% Auto-generated chapter 29 for malik
% Hadiths in this chapter: 118

\hadithdefcmd{malik}{1150}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، قَالَ لِعَبْدِ اللَّهِ بْنِ عَبَّاسٍ إِنِّي طَلَّقْتُ امْرَأَتِي مِائَةَ تَطْلِيقَةٍ فَمَاذَا تَرَى عَلَىَّ فَقَالَ لَهُ ابْنُ عَبَّاسٍ طَلُقَتْ مِنْكَ لِثَلاَثٍ وَسَبْعٌ وَتِسْعُونَ اتَّخَذْتَ بِهَا آيَاتِ اللَّهِ هُزُوًا ‏.‏\hadithno{1150}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that a man said to Abdullah ibn Abbas, "I have divorced my wife by saying I divorce you a hundred times. What do you think my situation is?" Ibn Abbas said to him, "She was divorced from you by three pronouncements, and by the ninety-seven, you have mocked the ayat of Allah}}
\hadithdefcmd{malik}{1151}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، جَاءَ إِلَى عَبْدِ اللَّهِ بْنِ مَسْعُودٍ فَقَالَ إِنِّي طَلَّقْتُ امْرَأَتِي ثَمَانِيَ تَطْلِيقَاتٍ ‏.‏ فَقَالَ ابْنُ مَسْعُودٍ فَمَاذَا قِيلَ لَكَ قَالَ قِيلَ لِي إِنَّهَا قَدْ بَانَتْ مِنِّي ‏.‏ فَقَالَ ابْنُ مَسْعُودٍ صَدَقُوا مَنْ طَلَّقَ كَمَا أَمَرَهُ اللَّهُ فَقَدْ بَيَّنَ اللَّهُ لَهُ وَمَنْ لَبَسَ عَلَى نَفْسِهِ لَبْسًا جَعَلْنَا لَبْسَهُ مُلْصَقًا بِهِ لاَ تَلْبِسُوا عَلَى أَنْفُسِكُمْ وَنَتَحَمَّلَهُ عَنْكُمْ هُوَ كَمَا يَقُولُونَ ‏.‏\hadithno{1151}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that a man came to Abdullah ibn Masud and said, "I have divorced my wife by saying I divorce you eight times." Ibn Masud said to him, "What have people told you?" He replied, "I have been told that I have to part absolutely from her." Ibn Masud said, "They have spoken the truth. A person who divorces as Allah has commanded, Allah makes it clear for him, and a person who obscures himself in error, we make stay by his error. So do not confuse yourselves and pull us into your confusion. It is as they have said}}
\hadithdefcmd{malik}{1152}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ حَزْمٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، قَالَ لَهُ الْبَتَّةُ مَا يَقُولُ النَّاسُ فِيهَا قَالَ أَبُو بَكْرٍ فَقُلْتُ لَهُ كَانَ أَبَانُ بْنُ عُثْمَانَ يَجْعَلُهَا وَاحِدَةً ‏.‏ فَقَالَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ لَوْ كَانَ الطَّلاَقُ أَلْفًا مَا أَبْقَتِ الْبَتَّةُ مِنْهَا شَيْئًا مَنْ قَالَ الْبَتَّةَ فَقَدْ رَمَى الْغَايَةَ الْقُصْوَى ‏.‏\hadithno{1152}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abu Bakr ibn Hazm thatUmar ibn Abd al-Aziz had asked him what people said about the 'irrevocable' divorce, and Abu Bakr had replied that Aban ibn Uthman had clarified that it was declared only once. Umar ibn Abd al- Aziz said, "Even if divorce had to be declared a thousand times, the'irrevocable' would use them all up. A person who says, 'irrevocably' has cast the furthest limit}}
\hadithdefcmd{malik}{1153}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، كَانَ يَقْضِي فِي الَّذِي يُطَلِّقُ امْرَأَتَهُ الْبَتَّةَ أَنَّهَا ثَلاَثُ تَطْلِيقَاتٍ ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{1153}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Marwan ibn al-Hakam decided that if someone made three pronouncements of divorce, he had divorced his wife irrevocably. Malik said, "That is what I like best of what I have heard on the subject." 29.2 Divorce by Euphemistic Statements}}
\hadithdefcmd{malik}{1154}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّهُ كُتِبَ إِلَى عُمَرَ بْنِ الْخَطَّابِ مِنَ الْعِرَاقَ أَنَّ رَجُلاً قَالَ لاِمْرَأَتِهِ حَبْلُكِ عَلَى غَارِبِكِ فَكَتَبَ عُمَرُ بْنُ الْخَطَّابِ إِلَى عَامِلِهِ أَنْ مُرْهُ يُوَافِينِي بِمَكَّةَ فِي الْمَوْسِمِ فَبَيْنَمَا عُمَرُ يَطُوفُ بِالْبَيْتِ إِذْ لَقِيَهُ الرَّجُلُ فَسَلَّمَ عَلَيْهِ فَقَالَ عُمَرُ مَنْ أَنْتَ فَقَالَ أَنَا الَّذِي أَمَرْتَ أَنْ أُجْلَبَ عَلَيْكَ ‏.‏ فَقَالَ لَهُ عُمَرُ أَسْأَلُكَ بِرَبِّ هَذِهِ الْبَنِيَّةِ مَا أَرَدْتَ بِقَوْلِكَ حَبْلُكِ عَلَى غَارِبِكِ فَقَالَ لَهُ الرَّجُلُ لَوِ اسْتَحْلَفْتَنِي فِي غَيْرِ هَذَا الْمَكَانِ مَا صَدَقْتُكَ أَرَدْتُ بِذَلِكَ الْفِرَاقَ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ هُوَ مَا أَرَدْتَ ‏.‏\hadithno{1154}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab had heard in a letter from Iraq that a man said to his wife, "Your rein is on your withers (i.e. you have free rein)." Umar ibn al-Khattab wrote to his governor to order the man to come to him at Makka at the time of hajj. While Umar was doing tawaf around the House, a man met him and greeted him. Umar asked him who he was, and he replied that he was the man that he had ordered to be brought to him. Umar said to him, "I ask you by the Lord of this building, what did you mean by your statement, 'Your rein is on your withers.'?" The man replied, "Had you made me swear by other than this place, I would not have told you the truth. I intended separation by that." Umar ibn al- Khattab said, "It is what you intended}}
\hadithdefcmd{malik}{1155}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، كَانَ يَقُولُ فِي الرَّجُلِ يَقُولُ لاِمْرَأَتِهِ أَنْتِ عَلَىَّ حَرَامٌ إِنَّهَا ثَلاَثُ تَطْلِيقَاتٍ ‏.‏ قَالَ مَالِكُ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُ فِي ذَلِكَ ‏.‏\hadithno{1155}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Ali ibn Abi Talib used to say that if a man said to his wife, "You are haram for me," it counted as three pronouncements of divorce. Malik said, "That is the best of what I have heard on the subject}}
\hadithdefcmd{malik}{1156}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ فِي الْخَلِيَّةِ وَالْبَرِيَّةِ إِنَّهَا ثَلاَثُ تَطْلِيقَاتٍ كُلُّ وَاحِدَةٍ مِنْهُمَا ‏.‏\hadithno{1156}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said that statements like "I cut myself off from you",or"You are abandoned", were considered as three pronouncements of divorce. Malik said that any strong statements such as these or others were considered as three pronouncements of divorce for a woman whose marriage had been consummated. In the case of a woman whose marriage had not been consummated, the man was asked to make an oath on his deen, as to whether he had intended one or three pronouncements of divorce. If he had intended one pronouncement, he was asked to make an oath by Allah to confirm it, and he became a suitor among other suitors, because a woman whose marriage had been consummated, required three pronouncements of divorce to make her inaccessible for the husband, whilst only one pronouncement was needed to make a woman whose marriage had not been consummated inaccessible. Malik added, "That is the best of what I have heard about the matter}}
\hadithdefcmd{malik}{1157}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، ‏.‏ أَنَّ رَجُلاً، كَانَتْ تَحْتَهُ وَلِيدَةٌ لِقَوْمٍ فَقَالَ لأَهْلِهَا شَأْنَكُمْ بِهَا ‏.‏ فَرَأَى النَّاسُ أَنَّهَا تَطْلِيقَةٌ وَاحِدَةٌ ‏.‏\hadithno{1157}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from al-Qasim ibn Muhammad that a certain man had taken a slave-girl belonging to somebody else as a wife. He said to her people, "She is your concern," and people considered that to be one pronouncement of divorce}}
\hadithdefcmd{malik}{1158}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ فِي الرَّجُلِ يَقُولُ لاِمْرَأَتِهِ بَرِئْتِ مِنِّي وَبَرِئْتُ مِنْكِ إِنَّهَا ثَلاَثُ تَطْلِيقَاتٍ بِمَنْزِلَةِ الْبَتَّةِ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَقُولُ لاِمْرَأَتِهِ أَنْتِ خَلِيَّةٌ أَوْ بَرِيَّةٌ أَوْ بَائِنَةٌ إِنَّهَا ثَلاَثُ تَطْلِيقَاتٍ لِلْمَرْأَةِ الَّتِي قَدْ دَخَلَ بِهَا وَيُدَيَّنُ فِي الَّتِي لَمْ يَدْخُلْ بِهَا أَوَاحِدَةً أَرَادَ أَمْ ثَلاَثًا فَإِنْ قَالَ وَاحِدَةً أُحْلِفَ عَلَى ذَلِكَ وَكَانَ خَاطِبًا مِنَ الْخُطَّابِ لأَنَّهُ لاَ يُخْلِي الْمَرْأَةَ الَّتِي قَدْ دَخَلَ بِهَا زَوْجُهَا وَلاَ يُبِينُهَا وَلاَ يُبْرِيهَا إِلاَّ ثَلاَثُ تَطْلِيقَاتٍ وَالَّتِي لَمْ يَدْخُلْ بِهَا تُخْلِيهَا وَتُبْرِيهَا وَتُبِينُهَا الْوَاحِدَةُ ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحْسَنُ مَا سَمِعْتُ فِي ذَلِكَ ‏.‏\hadithno{1158}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard Ibn Shihab say that if a man said to his wife, "You are free of me, and I am free of you, " it counted as three pronouncements of divorce as if it were an 'irrevocable' divorce. Malik said that if a man made any strong statement such as these to his wife, it counted as three pronouncements of divorce for a woman whose marriage had been consummated, or it was written as one of three for a woman whose marriage had not been consummated, whichever the man wished. If he said he intended only one divorce he swore to it and he became one of the suitors because, whereas a woman whose marriage had been consummated was made inaccessible by three pronouncements of divorce, the woman whose marriage had not been consummated was made inaccessible by only one pronouncement. Malik said, "That is the best of what I have heard}}
\hadithdefcmd{malik}{1159}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، جَاءَ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنِّي جَعَلْتُ أَمْرَ امْرَأَتِي فِي يَدِهَا فَطَلَّقَتْ نَفْسَهَا فَمَاذَا تَرَى فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أُرَاهُ كَمَا قَالَتْ ‏.‏ فَقَالَ الرَّجُلُ لاَ تَفْعَلْ يَا أَبَا عَبْدِ الرَّحْمَنِ ‏.‏ فَقَالَ ابْنُ عُمَرَ أَنَا أَفْعَلُ أَنْتَ فَعَلْتَهُ ‏.‏\hadithno{1159}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that a man came to Abdullah ibn Umar, and said, "Abu Abd ar-Rahman! I placed the command of my wife in her hand, and she divorced herself, what do you think?" Abdullah ibn Umar said, "I think that it is as she said." The man said, "Don't do it, Abu Abd ar-Rahman!" Ibn Umar said, "You did it, it has nothing to do with me}}
\hadithdefcmd{malik}{1160}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا مَلَّكَ الرَّجُلُ امْرَأَتَهُ أَمْرَهَا فَالْقَضَاءُ مَا قَضَتْ بِهِ إِلاَّ أَنْ يُنْكِرَ عَلَيْهَا وَيَقُولَ لَمْ أُرِدْ إِلاَّ وَاحِدَةً فَيَحْلِفُ عَلَى ذَلِكَ وَيَكُونُ أَمْلَكَ بِهَا مَا كَانَتْ فِي عِدَّتِهَا ‏.‏\hadithno{1160}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "When a man gives a woman command over herself, then the result is as she decides unless he denies it and says that he only meant to give her one divorce and he swears to it - then he has access to her while she is in her idda}}
\hadithdefcmd{malik}{1161}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ سُلَيْمَانَ بْنِ زَيْدِ بْنِ ثَابِتٍ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، كَانَ جَالِسًا عِنْدَ زَيْدِ بْنِ ثَابِتٍ فَأَتَاهُ مُحَمَّدُ بْنُ أَبِي عَتِيقٍ وَعَيْنَاهُ تَدْمَعَانِ فَقَالَ لَهُ زَيْدٌ مَا شَأْنُكَ فَقَالَ مَلَّكْتُ امْرَأَتِي أَمْرَهَا فَفَارَقَتْنِي ‏.‏ فَقَالَ لَهُ زَيْدٌ مَا حَمَلَكَ عَلَى ذَلِكَ قَالَ الْقَدَرُ ‏.‏ فَقَالَ زَيْدٌ ارْتَجِعْهَا إِنْ شِئْتَ فَإِنَّمَا هِيَ وَاحِدَةٌ وَأَنْتَ أَمْلَكُ بِهَا ‏.‏\hadithno{1161}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Sulayman ibn Zayd ibn Thabit that Kharija ibn Zayd ibn Thabit told him that he was sitting with Zayd ibn Thabit when Muhammad ibn Abi Atiq came to him with his eyes brimming with tears. Zayd asked him what the matter was. He said, "I gave my wife command of herself, and she separated from me." Zayd said to him, "What made you do that?" He said, "The Decree." Zayd said, "Return to her if you wish for it is only one pronouncement, and you have access to her}}
\hadithdefcmd{malik}{1162}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، مِنْ ثَقِيفٍ مَلَّكَ امْرَأَتَهُ أَمْرَهَا فَقَالَتْ أَنْتَ الطَّلاَقُ فَسَكَتَ ثُمَّ قَالَتْ أَنْتَ الطَّلاَقُ فَقَالَ بِفِيكِ الْحَجَرُ ‏.‏ ثُمَّ قَالَتْ أَنْتَ الطَّلاَقُ فَقَالَ بِفِيكِ الْحَجَرُ ‏.‏ فَاخْتَصَمَا إِلَى مَرْوَانَ بْنِ الْحَكَمِ فَاسْتَحْلَفَهُ مَا مَلَّكَهَا إِلاَّ وَاحِدَةً وَرَدَّهَا إِلَيْهِ ‏.‏ قَالَ مَالِكٌ قَالَ عَبْدُ الرَّحْمَنِ فَكَانَ الْقَاسِمُ يُعْجِبُهُ هَذَا الْقَضَاءُ وَيَرَاهُ أَحْسَنَ مَا سَمِعَ فِي ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحْسَنُ مَا سَمِعْتُ فِي ذَلِكَ وَأَحَبُّهُ إِلَىَّ ‏.‏\hadithno{1162}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that a man of Thaqif gave his wife command over herself, and she said, "You are divorced." He was silent. She said, "You are divorced." He said, "May a stone be in your mouth." She said, "You are divorced." He said, "May a stone be in your mouth." They argued and went to Marwan ibn al-Hakam. He took an oath that he had only given her control over one pronouncement, and then she returned to him. Malik said that Abd ar-Rahman declared that this decision had amazed al-Qasim, who thought it the best that he had heard on the subject. Malik added, "That is also the best of what I have heard on the subject}}
\hadithdefcmd{malik}{1163}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا خَطَبَتْ عَلَى عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ قُرَيْبَةَ بِنْتَ أَبِي أُمَيَّةَ فَزَوَّجُوهُ ثُمَّ إِنَّهُمْ عَتَبُوا عَلَى عَبْدِ الرَّحْمَنِ وَقَالُوا مَا زَوَّجْنَا إِلاَّ عَائِشَةَ فَأَرْسَلَتْ عَائِشَةُ إِلَى عَبْدِ الرَّحْمَنِ فَذَكَرَتْ ذَلِكَ لَهُ فَجَعَلَ أَمْرَ قُرَيْبَةَ بِيَدِهَا فَاخْتَارَتْ زَوْجَهَا فَلَمْ يَكُنْ ذَلِكَ طَلاَقًا ‏.‏\hadithno{1163}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that A'isha, umm al-muminin, proposed to Qurayba bint Abi Umayya on behalf of Abd ar-Rahman ibn Abi Bakr. They married her to him and her people found fault with Abd ar-Rahman and said, "We only gave in marriage because of A'isha." A'isha therefore sent for Abd ar-Rahman and told him about it. He gave Qurayba authority over herself and she chose her husband and so there was no divorce}}
\hadithdefcmd{malik}{1164}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم زَوَّجَتْ حَفْصَةَ بِنْتَ عَبْدِ الرَّحْمَنِ الْمُنْذِرَ بْنَ الزُّبَيْرِ - وَعَبْدُ الرَّحْمَنِ غَائِبٌ بِالشَّامِ - فَلَمَّا قَدِمَ عَبْدُ الرَّحْمَنِ قَالَ وَمِثْلِي يُصْنَعُ هَذَا بِهِ وَمِثْلِي يُفْتَاتُ عَلَيْهِ فَكَلَّمَتْ عَائِشَةُ الْمُنْذِرَ بْنَ الزُّبَيْرِ فَقَالَ الْمُنْذِرُ فَإِنَّ ذَلِكَ بِيَدِ عَبْدِ الرَّحْمَنِ ‏.‏ فَقَالَ عَبْدُ الرَّحْمَنِ مَا كُنْتُ لأَرُدَّ أَمْرًا قَضَيْتِيهِ فَقَرَّتْ حَفْصَةُ عِنْدَ الْمُنْذِرِ وَلَمْ يَكُنْ ذَلِكَ طَلاَقًا ‏.‏\hadithno{1164}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, gave Hafsa bint Abd arRahman in marriage to al-Mundhir ibn az-Zubayr while Abd ar-Rahman was away in Syria. When Abd ar-Rahman arrived, he said, "Shall someone like me have this done to him? Am I the kind of man to have something done to him without his consent?" A'isha spoke to al-Mundhir ibn az-Zubayr, and al-Mundhir said, "It is in the hands of Abd ar-Rahman." Abd ar-Rahman said, "I won't oppose something that you have already completed." Hafsa was confirmed with al-Mundhir, and there was no divorce}}
\hadithdefcmd{malik}{1165}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَأَبَا، هُرَيْرَةَ سُئِلاَ عَنِ الرَّجُلِ، يُمَلِّكُ امْرَأَتَهُ أَمْرَهَا فَتَرُدُّ ذَلِكَ إِلَيْهِ وَلاَ تَقْضِي فِيهِ شَيْئًا فَقَالاَ لَيْسَ ذَلِكَ بِطَلاَقٍ ‏.‏\hadithno{1165}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar and Abu Hurayra were asked about a man who gave his wife power over herself, and she returned it to him without doing anything with it. They said that there was no divorce. (i.e. The man's giving his wife power over herself was not interpreted as a desire for divorce on his part)}}
\hadithdefcmd{malik}{1166}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ إِذَا مَلَّكَ الرَّجُلُ امْرَأَتَهُ أَمْرَهَا فَلَمْ تُفَارِقْهُ وَقَرَّتْ عِنْدَهُ فَلَيْسَ ذَلِكَ بِطَلاَقٍ ‏.‏ قَالَ مَالِكٌ فِي الْمُمَلَّكَةِ إِذَا مَلَّكَهَا زَوْجُهَا أَمْرَهَا ثُمَّ افْتَرَقَا وَلَمْ تَقْبَلْ مِنْ ذَلِكَ شَيْئًا فَلَيْسَ بِيَدِهَا مِنْ ذَلِكَ شَىْءٌ وَهُوَ لَهَا مَا دَامَا فِي مَجْلِسِهِمَا ‏.‏\hadithno{1166}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "If a man gives his wife authority over herself, and she does not separate from him and remains with him, there is no divorce." Malik said that a woman whose husband gave her power over herself and they separated while she was unwilling, had no power to revoke the divorce. She only had power over herself as long as they remained together}}
\hadithdefcmd{malik}{1167}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّهُ كَانَ يَقُولُ إِذَا آلَى الرَّجُلُ مِنِ امْرَأَتِهِ لَمْ يَقَعْ عَلَيْهِ طَلاَقٌ وَإِنْ مَضَتِ الأَرْبَعَةُ الأَشْهُرِ حَتَّى يُوقَفَ فَإِمَّا أَنْ يُطَلِّقَ وَإِمَّا أَنْ يَفِيءَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1167}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father that Ali ibn Abi Talib said, "When a man takes a vow to abstain from intercourse, divorce does not occur immediately. If four months pass, he must declare his intent and either he is divorced or he revokes his vow . " Malik said, "That is what is done among us}}
\hadithdefcmd{malik}{1168}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ أَيُّمَا رَجُلٍ آلَى مِنِ امْرَأَتِهِ فَإِنَّهُ إِذَا مَضَتِ الأَرْبَعَةُ الأَشْهُرِ وُقِفَ حَتَّى يُطَلِّقَ أَوْ يَفِيءَ وَلاَ يَقَعُ عَلَيْهِ طَلاَقٌ إِذَا مَضَتِ الأَرْبَعَةُ الأَشْهُرِ حَتَّى يُوقَفَ ‏.‏\hadithno{1168}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "When a man makes a vow to abstain from intercourse with his wife and four months have passed he must declare his intent and either he is divorced or he revokes his vow. Divorce does not occur until four months have passed and he continues to abstain}}
\hadithdefcmd{malik}{1169}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَأَبَا، بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ كَانَا يَقُولاَنِ فِي الرَّجُلِ يُولِي مِنِ امْرَأَتِهِ إِنَّهَا إِذَا مَضَتِ الأَرْبَعَةُ الأَشْهُرِ فَهِيَ تَطْلِيقَةٌ وَلِزَوْجِهَا عَلَيْهَا الرَّجْعَةُ مَا كَانَتْ فِي الْعِدَّةِ ‏.‏\hadithno{1169}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said al-Musayyab and Abu Bakr ibn Abd ar-Rahman said about a man who made a vow to abstain from intercourse with his wife, "If four months pass it is a divorce. The husband can go back to his wife as long as she is in her idda}}
\hadithdefcmd{malik}{1170}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، كَانَ يَقْضِي فِي الرَّجُلِ إِذَا آلَى مِنِ امْرَأَتِهِ أَنَّهَا إِذَا مَضَتِ الأَرْبَعَةُ الأَشْهُرِ فَهِيَ تَطْلِيقَةٌ وَلَهُ عَلَيْهَا الرَّجْعَةُ مَا دَامَتْ فِي عِدَّتِهَا ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ كَانَ رَأْىُ ابْنِ شِهَابٍ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يُولِي مِنِ امْرَأَتِهِ فَيُوقَفُ فَيُطَلِّقُ عِنْدَ انْقِضَاءِ الأَرْبَعَةِ الأَشْهُرِ ثُمَّ يُرَاجِعُ امْرَأَتَهُ أَنَّهُ إِنْ لَمْ يُصِبْهَا حَتَّى تَنْقَضِيَ عِدَّتُهَا فَلاَ سَبِيلَ لَهُ إِلَيْهَا وَلاَ رَجْعَةَ لَهُ عَلَيْهَا إِلاَّ أَنْ يَكُونَ لَهُ عُذْرٌ مِنْ مَرَضٍ أَوْ سِجْنٍ أَوْ مَا أَشْبَهَ ذَلِكَ مِنَ الْعُذْرِ فَإِنَّ ارْتِجَاعَهُ إِيَّاهَا ثَابِتٌ عَلَيْهَا فَإِنْ مَضَتْ عِدَّتُهَا ثُمَّ تَزَوَّجَهَا بَعْدَ ذَلِكَ فَإِنَّهُ إِنْ لَمْ يُصِبْهَا حَتَّى تَنْقَضِيَ الأَرْبَعَةُ الأَشْهُرِ وَقَفَ أَيْضًا فَإِنْ لَمْ يَفِئْ دَخَلَ عَلَيْهِ الطَّلاَقُ بِالإِيلاَءِ الأَوَّلِ إِذَا مَضَتِ الأَرْبَعَةُ الأَشْهُرِ وَلَمْ يَكُنْ لَهُ عَلَيْهَا رَجْعَةٌ لأَنَّهُ نَكَحَهَا ثُمَّ طَلَّقَهَا قَبْلَ أَنْ يَمَسَّهَا فَلاَ عِدَّةَ لَهُ عَلَيْهَا وَلاَ رَجْعَةَ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يُولِي مِنِ امْرَأَتِهِ فَيُوقَفُ بَعْدَ الأَرْبَعَةِ الأَشْهُرِ فَيُطَلِّقُ ثُمَّ يَرْتَجِعُ وَلاَ يَمَسُّهَا فَتَنْقَضِي أَرْبَعَةُ أَشْهُرٍ قَبْلَ أَنْ تَنْقَضِيَ عِدَّتُهَا إِنَّهُ لاَ يُوقَفُ وَلاَ يَقَعُ عَلَيْهِ طَلاَقٌ وَإِنَّهُ إِنْ أَصَابَهَا قَبْلَ أَنْ تَنْقَضِيَ عِدَّتُهَا كَانَ أَحَقَّ بِهَا وَإِنْ مَضَتْ عِدَّتُهَا قَبْلَ أَنْ يُصِيبَهَا فَلاَ سَبِيلَ لَهُ إِلَيْهَا وَهَذَا أَحْسَنُ مَا سَمِعْتُ فِي ذَلِكَ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يُولِي مِنِ امْرَأَتِهِ ثُمَّ يُطَلِّقُهَا فَتَنْقَضِي الأَرْبَعَةُ الأَشْهُرِ قَبْلَ انْقِضَاءِ عِدَّةِ الطَّلاَقِ قَالَ هُمَا تَطْلِيقَتَانِ إِنْ هُوَ وُقِفَ وَلَمْ يَفِئْ وَإِنْ مَضَتْ عِدَّةُ الطَّلاَقِ قَبْلَ الأَرْبَعَةِ الأَشْهُرِ فَلَيْسَ الإِيلاَءُ بِطَلاَقٍ وَذَلِكَ أَنَّ الأَرْبَعَةَ الأَشْهُرِ الَّتِي كَانَتْ تُوقَفُ بَعْدَهَا مَضَتْ وَلَيْسَتْ لَهُ يَوْمَئِذٍ بِامْرَأَةٍ ‏.‏ قَالَ مَالِكٌ وَمَنْ حَلَفَ أَنْ لاَ يَطَأَ امْرَأَتَهُ يَوْمًا أَوْ شَهْرًا ثُمَّ مَكَثَ حَتَّى يَنْقَضِيَ أَكْثَرُ مِنَ الأَرْبَعَةِ الأَشْهُرِ فَلاَ يَكُونُ ذَلِكَ إِيلاَءً وَإِنَّمَا يُوقَفُ فِي الإِيلاَءِ مَنْ حَلَفَ عَلَى أَكْثَرَ مِنَ الأَرْبَعَةِ الأَشْهُرِ فَأَمَّا مَنْ حَلَفَ أَنْ لاَ يَطَأَ امْرَأَتَهُ أَرْبَعَةَ أَشْهُرٍ أَوْ أَدْنَى مِنْ ذَلِكَ فَلاَ أَرَى عَلَيْهِ إِيلاَءً لأَنَّهُ إِذَا دَخَلَ الأَجَلُ الَّذِي يُوقَفُ عِنْدَهُ خَرَجَ مِنْ يَمِينِهِ وَلَمْ يَكُنْ عَلَيْهِ وَقْفٌ ‏.‏ قَالَ مَالِكٌ مَنْ حَلَفَ لاِمْرَأَتِهِ أَنْ لاَ يَطَأَهَا حَتَّى تَفْطِمَ وَلَدَهَا فَإِنَّ ذَلِكَ لاَ يَكُونُ إِيلاَءً ‏.‏\hadithno{1170}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Marwan ibn al-Hakam decided about a man who had made a vow to abstain from intercourse with his wife, that when four months had passed, it was a divorce and he could return to her as long as she was in her idda. Malik added, "That was also the opinion of Ibn Shihab." Malik said that if a man made a vow to abstain from intercourse with his wife and at the end of four months he declared his intent to continue to abstain, he was divorced. He could go back to his wife, but if he did not have intercourse with her before the end of her idda, he had no access to her and he could not go back to her unless he had an excuse - illness, imprisonment, or a similar excuse. His return to her maintained her as his wife. If her idda passed and then he married her after that and did not have intercourse with her until four months had passed and he declared his intent to continue to abstain, divorce was applied to him by the first vow. If four months passed, and he had not returned to her, he had no idda against her nor access because he had married her and then divorced her before touching her. Malik said that a man who made a vow to abstain from intercourse with his wife and continued to abstain after four months and so divorced her, but then returned and did not touch her and four months were completed before her idda was completed, did not have to declare his intent and divorce did not befall him. If he had intercourse with her before the end of her idda, he was entitled to her. If her idda passed before he had intercourse with her, he had no access to her. This is what Malik preferred of what he had heard on the subject. Malik said that if a man made a vow to abstain from intercourse with his wife and then divorced her, and the four months of the vow were completed before completion of the idda of the divorce, it counted as two pronouncements of divorce. If he declared his intention to continue to abstain and the idda of the divorce finished before the four months the vow of abstention was not a divorce. That was because the four months had passed and she was not his on that day. Malik said, "If someone makes a vow not to have intercourse with his wife for a day or a month and then waits until more than four months have passed, it is not ila. Ila only applies to someone who vows more than four months. As for the one who vows not to have intercourse with his wife for four months or less than that, I do not think that it is ila because when the term enters into it at which it stops, he comes out of his oath and he does not have to declare his intention." Malik said, "If someone vows to his wife not to have intercourse with her until her child has been weaned, that is not ila. I have heard that Ali ibn Abi Talib was asked about that and he did not think that it was ila}}
\hadithdefcmd{malik}{1172}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنْ إِيلاَءِ الْعَبْدِ، فَقَالَ هُوَ نَحْوُ إِيلاَءِ الْحُرِّ وَهُوَ عَلَيْهِ وَاجِبٌ وَإِيلاَءُ الْعَبْدِ شَهْرَانِ ‏.‏\hadithno{1172}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had asked Ibn Shihab about the ila of the slave. He said that it was like the ila of the free man, and it put an obligation on him. The ila of the slave was two months}}
\hadithdefcmd{malik}{1173}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، أَنَّهُ سَأَلَ الْقَاسِمَ بْنَ مُحَمَّدٍ عَنْ رَجُلٍ، طَلَّقَ امْرَأَةً إِنْ هُوَ تَزَوَّجَهَا فَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ إِنَّ رَجُلاً جَعَلَ امْرَأَةً عَلَيْهِ كَظَهْرِ أُمِّهِ إِنْ هُوَ تَزَوَّجَهَا فَأَمَرَهُ عُمَرُ بْنُ الْخَطَّابِ إِنْ هُوَ تَزَوَّجَهَا أَنْ لاَ يَقْرَبَهَا حَتَّى يُكَفِّرَ كَفَّارَةَ الْمُتَظَاهِرِ ‏.‏\hadithno{1173}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Amr ibn Sulaym az- Zuraqi that he asked al-Qasim ibn Muhammad about a man who made divorce conditional on his marrying a woman i.e. if he married her he would automatically divorce her. Al-Qasim ibn Muhammad said, "If a man marries a woman whom he has made as his mother's back, i.e. has made haram for him, Umar ibn al-Khattab ordered him not to go near her if he married her until he had done the kaffara for pronouncing dhihar}}
\hadithdefcmd{malik}{1174}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، سَأَلَ الْقَاسِمَ بْنَ مُحَمَّدٍ وَسُلَيْمَانَ بْنَ يَسَارٍ عَنْ رَجُلٍ تَظَاهَرَ مِنِ امْرَأَتِهِ قَبْلَ أَنْ يَنْكِحَهَا فَقَالاَ إِنْ نَكَحَهَا فَلاَ يَمَسَّهَا حَتَّى يُكَفِّرَ كَفَّارَةَ الْمُتَظَاهِرِ ‏.‏\hadithno{1174}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that a man asked al-Qasim ibn Muhammad and Sulayman ibn Yasar about a man who pronounced dhihar from his wife before he had married her. They said, "If he marries her, he must not touch her until he has done the kaffara for pronouncing dhihar}}
\hadithdefcmd{malik}{1175}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ فِي رَجُلٍ تَظَاهَرَ مِنْ أَرْبَعَةِ نِسْوَةٍ لَهُ بِكَلِمَةٍ وَاحِدَةٍ إِنَّهُ لَيْسَ عَلَيْهِ إِلاَّ كَفَّارَةٌ وَاحِدَةٌ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، مِثْلَ ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ الأَمْرُ عِنْدَنَا قَالَ اللَّهُ تَعَالَى فِي كَفَّارَةِ الْمُتَظَاهِرِ ‏\{‏فَتَحْرِيرُ رَقَبَةٍ مِنْ قَبْلِ أَنْ يَتَمَاسَّا ‏\}‏‏.‏ ‏\{‏فَمَنْ لَمْ يَجِدْ فَصِيَامُ شَهْرَيْنِ مُتَتَابِعَيْنِ مِنْ قَبْلِ أَنْ يَتَمَاسَّا فَمَنْ لَمْ يَسْتَطِعْ فَإِطْعَامُ سِتِّينَ مِسْكِينًا‏\}‏ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَتَظَاهَرُ مِنِ امْرَأَتِهِ فِي مَجَالِسَ مُتَفَرِّقَةٍ قَالَ لَيْسَ عَلَيْهِ إِلاَّ كَفَّارَةٌ وَاحِدَةٌ فَإِنْ تَظَاهَرَ ثُمَّ كَفَّرَ ثُمَّ تَظَاهَرَ بَعْدَ أَنْ يُكَفِّرَ فَعَلَيْهِ الْكَفَّارَةُ أَيْضًا ‏.‏ قَالَ مَالِكٌ وَمَنْ تَظَاهَرَ مِنِ امْرَأَتِهِ ثُمَّ مَسَّهَا قَبْلَ أَنْ يُكَفِّرَ لَيْسَ عَلَيْهِ إِلاَّ كَفَّارَةٌ وَاحِدَةٌ وَيَكُفُّ عَنْهَا حَتَّى يُكَفِّرَ وَلْيَسْتَغْفِرِ اللَّهَ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُ ‏.‏ قَالَ مَالِكٌ وَالظِّهَارُ مِنْ ذَوَاتِ الْمَحَارِمِ مِنَ الرَّضَاعَةِ وَالنَّسَبِ سَوَاءٌ ‏.‏ قَالَ مَالِكٌ وَلَيْسَ عَلَى النِّسَاءِ ظِهَارٌ ‏.‏ قَالَ مَالِكٌ فِي قَوْلِ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏وَالَّذِينَ يُظَاهِرُونَ مِنْ نِسَائِهِمْ ثُمَّ يَعُودُونَ لِمَا قَالُوا‏\}‏‏.‏ قَالَ سَمِعْتُ أَنَّ تَفْسِيرَ ذَلِكَ أَنْ يَتَظَاهَرَ الرَّجُلُ مِنِ امْرَأَتِهِ ثُمَّ يُجْمِعَ عَلَى إِمْسَاكِهَا وَإِصَابَتِهَا فَإِنْ أَجْمَعَ عَلَى ذَلِكَ فَقَدْ وَجَبَتْ عَلَيْهِ الْكَفَّارَةُ وَإِنْ طَلَّقَهَا وَلَمْ يُجْمِعْ بَعْدَ تَظَاهُرِهِ مِنْهَا عَلَى إِمْسَاكِهَا وَإِصَابَتِهَا فَلاَ كَفَّارَةَ عَلَيْهِ ‏.‏ قَالَ مَالِكٌ فَإِنْ تَزَوَّجَهَا بَعْدَ ذَلِكَ لَمْ يَمَسَّهَا حَتَّى يُكَفِّرَ كَفَّارَةَ الْمُتَظَاهِرِ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَتَظَاهَرُ مِنْ أَمَتِهِ إِنَّهُ إِنْ أَرَادَ أَنْ يُصِيبَهَا فَعَلَيْهِ كَفَّارَةُ الظِّهَارِ قَبْلَ أَنْ يَطَأَهَا ‏.‏ قَالَ مَالِكٌ لاَ يَدْخُلُ عَلَى الرَّجُلِ إِيلاَءٌ فِي تَظَاهُرِهِ إِلاَّ أَنْ يَكُونَ مُضَارًّا لاَ يُرِيدُ أَنْ يَفِيءَ مِنْ تَظَاهُرِهِ ‏\hadithno{1175}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said that a man who pronounced a dhihar from his four wives in one statement, had only to do one kaffara. Yahya related the same as that to me from Malik from Rabia ibn Abi Abd ar-Rahman. Malik said, "That is what is done among us. Allah, the Exalted said about the kaffara for pronouncing dhihar, 'It is to free a slave before they touch one another. If he does not find the means to do that, then fasting for two consecutive months before they touch one another. If he cannot do that, it is to feed sixty poor people. ' " (Sura 58 ayats 4,5). Malik said that a man who pronounced dhihar from his wife on various occasions had only to do one kaffara. If he pronounced dhihar, and then did kaffara, and then pronounced dhihar after he had done the kaffara, he had to do kaffara again. Malik said, "Some one who pronounces dhihar from his wife and then has intercourse with her before he has done kaffara, only has to do one kaffara. He must abstain from her until he does kaffara and ask forgiveness of Allah. That is the best of what I have heard. " Malik said, "It is the same with dhihar using any prohibited relations of fosterage and ancestry." Malik said, "Women have no dhihar." Malik said that he had heard that the commentary on the word of Allah, the Blessed, the Exalted, "Those of you who pronounce the dhihar about their wives, and then retract what they have said," (Sura 56 ayat 3), was that a man pronounced dhihar on his wife and then decided to keep her and have intercourse with her. If he decided on that, he must do kaffara. If he divorced her and did not decide to retract his dhihar of her and to keep her and have intercourse with her, there would be no kaffara incumbent on him. Maliksaid, "If he marries her after that, he does not touch her until he has completed the kaffara of pronouncing dhihar." Malik said that if a man who pronounced dhihar from his slave-girl wanted to have intercourse with her, he had to do the kaffara of the dhihar before he could sleep with her. Malik said, "There is no ila in a man's dhihar unless it is evident that he does not intend to retract his dhihar}}
\hadithdefcmd{malik}{1177}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّهُ سَمِعَ رَجُلاً، يَسْأَلُ عُرْوَةَ بْنَ الزُّبَيْرِ عَنْ رَجُلٍ، قَالَ لاِمْرَأَتِهِ كُلُّ امْرَأَةٍ أَنْكِحُهَا عَلَيْكِ مَا عِشْتِ فَهِيَ عَلَىَّ كَظَهْرِ أُمِّي ‏.‏ فَقَالَ عُرْوَةُ بْنُ الزُّبَيْرِ يُجْزِئُهُ عَنْ ذَلِكَ عِتْقُ رَقَبَةٍ ‏.‏\hadithno{1177}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that he heard a man ask Urwa ibn az-Zubayr about a man who said to his wife, "Any woman I marry along with you as long as you live will be like my mother's back to me." Urwa ibn az-Zubayr said, "The freeing of slaves is enough to release him from that}}
\hadithdefcmd{malik}{1178}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنْ ظِهَارِ الْعَبْدِ، فَقَالَ نَحْوُ ظِهَارِ الْحُرِّ ‏.‏ قَالَ مَالِكٌ يُرِيدُ أَنَّهُ يَقَعُ عَلَيْهِ كَمَا يَقَعُ عَلَى الْحُرِّ ‏.‏ قَالَ مَالِكٌ وَظِهَارُ الْعَبْدِ عَلَيْهِ وَاجِبٌ وَصِيَامُ الْعَبْدِ فِي الظِّهَارِ شَهْرَانِ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ يَتَظَاهَرُ مِنِ امْرَأَتِهِ إِنَّهُ لاَ يَدْخُلُ عَلَيْهِ إِيلاَءٌ وَذَلِكَ أَنَّهُ لَوْ ذَهَبَ يَصُومُ صِيَامَ كَفَّارَةِ الْمُتَظَاهِرِ دَخَلَ عَلَيْهِ طَلاَقُ الإِيلاَءِ قَبْلَ أَنْ يَفْرُغَ مِنْ صِيَامِهِ ‏.‏\hadithno{1178}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{ahya related to me from Malik that he asked Ibn Shihab about the dhihar of a slave. He said, "It is like the dhihar of a free man." Malik said, "He meant that the same conditions were applied in both cases." Malik said, "The dhihar of the slave is incumbent on him, and the fasting of the slave in the dhihar is two months. " Malik said that there was no ila for a slave who pronounced a dhihar from his wife. That was because if he were to fast the kaffara for pronouncing a dhihar, the divorce of the ila would come to him before he had finished the fast}}
\hadithdefcmd{malik}{1179}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ كَانَ فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ فَكَانَتْ إِحْدَى السُّنَنِ الثَّلاَثِ أَنَّهَا أُعْتِقَتْ فَخُيِّرَتْ فِي زَوْجِهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْبُرْمَةُ تَفُورُ بِلَحْمٍ فَقُرِّبَ إِلَيْهِ خُبْزٌ وَأُدْمٌ مِنْ أُدْمِ الْبَيْتِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ أَرَ بُرْمَةً فِيهَا لَحْمٌ ‏"‏ ‏.‏ فَقَالُوا بَلَى يَا رَسُولَ اللَّهِ وَلَكِنْ ذَلِكَ لَحْمٌ تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ وَأَنْتَ لاَ تَأْكُلُ الصَّدَقَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ وَهُوَ لَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{1179}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman from al-Qasim ibn Muhammad that A'isha umm al-muminin, said, "There were three sunnas established in connection with Barira:firstly was that when she was set free she was given her choice about her husband, secondly, the Messenger of Allah, may Allah bless him and grant him peace, said about her, 'The right of inheritance belongs to the person who has set a person free,' thirdly, the Messenger of Allah, may Allah bless him and grant him peace, came in and there was a pot with meat on the boil. Bread and condiments were brought to him from the stock of the house. The Messenger of Allah, may Allah bless him and grant him peace, said, 'Didn't I see a pot with meat in it?' They said, 'Yes, Messenger of Allah. That is meat which was given as sadaqa for Barira, and you do not eat sadaqa.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'It is sadaqa for her, and it is a gift for us}}
\hadithdefcmd{malik}{1180}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ فِي الأَمَةِ تَكُونُ تَحْتَ الْعَبْدِ فَتَعْتِقُ إِنَّ الأَمَةَ لَهَا الْخِيَارُ مَا لَمْ يَمَسَّهَا ‏.‏ قَالَ مَالِكٌ وَإِنْ مَسَّهَا زَوْجُهَا فَزَعَمَتْ أَنَّهَا جَهِلَتْ أَنَّ لَهَا الْخِيَارَ فَإِنَّهَا تُتَّهَمُ وَلاَ تُصَدَّقُ بِمَا ادَّعَتْ مِنَ الْجَهَالَةِ وَلاَ خِيَارَ لَهَا بَعْدَ أَنْ يَمَسَّهَا ‏.‏\hadithno{1180}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{ahya related to me from Malik from Nafi that Abdullah ibn Umar said that a female slave who was the wife of a slave and then was set free, had the right of choice as long as he did not have intercourse with her. Malik said, "If her husband has intercourse with her and she claims that she did not know, she still has the right of choice. If she is suspect and one does not believe her claim of ignorance, then she has no choice after he has had intercourse with her}}
\hadithdefcmd{malik}{1181}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ مَوْلاَةً، لِبَنِي عَدِيٍّ يُقَالُ لَهَا زَبْرَاءُ أَخْبَرَتْهُ أَنَّهَا كَانَتْ تَحْتَ عَبْدٍ وَهِيَ أَمَةٌ يَوْمَئِذٍ فَعَتَقَتْ قَالَتْ فَأَرْسَلَتْ إِلَىَّ حَفْصَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم فَدَعَتْنِي فَقَالَتْ إِنِّي مُخْبِرَتُكِ خَبَرًا وَلاَ أُحِبُّ أَنْ تَصْنَعِي شَيْئًا إِنَّ أَمْرَكِ بِيَدِكِ مَا لَمْ يَمْسَسْكِ زَوْجُكِ فَإِنْ مَسَّكِ فَلَيْسَ لَكِ مِنَ الأَمْرِ شَىْءٌ ‏.‏ قَالَتْ فَقُلْتُ هُوَ الطَّلاَقُ ثُمَّ الطَّلاَقُ ثُمَّ الطَّلاَقُ ‏.‏ فَفَارَقَتْهُ ثَلاَثًا ‏.‏\hadithno{1181}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that a mawla of the tribe of Banu Adi called Zabra told him that she had been the wife of a slave when she was a slave-girl. Then she was set free and she sent a message to Hafsa, the wife of the Prophet, may Allah bless him and grant him peace. Hafsa called her and said, "I will tell you something., but I would prefer that you did not act upon it. You have authority over yourself as long as your husband does not have intercourse with you. If he has intercourse with you, you have no authority at all." Therefore she pronounced her divorce from him three times}}
\hadithdefcmd{malik}{1182}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ أَيُّمَا رَجُلٍ تَزَوَّجَ امْرَأَةً وَبِهِ جُنُونٌ أَوْ ضَرَرٌ فَإِنَّهَا تُخَيَّرُ فَإِنْ شَاءَتْ قَرَّتْ وَإِنْ شَاءَتْ فَارَقَتْ ‏.‏ قَالَ مَالِكٌ فِي الأَمَةِ تَكُونُ تَحْتَ الْعَبْدِ ثُمَّ تَعْتِقُ قَبْلَ أَنْ يَدْخُلَ بِهَا أَوْ يَمَسَّهَا إِنَّهَا إِنِ اخْتَارَتْ نَفْسَهَا فَلاَ صَدَاقَ لَهَا وَهِيَ تَطْلِيقَةٌ وَذَلِكَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1182}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab said that if a man married a woman, and he was insane or had a physical defect, she had the right of choice. If she wished she could stay, and if she wished she could separate from him}}
\hadithdefcmd{malik}{1183}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سَمِعَهُ يَقُولُ إِذَا خَيَّرَ الرَّجُلُ امْرَأَتَهُ فَاخْتَارَتْهُ فَلَيْسَ ذَلِكَ بِطَلاَقٍ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُ ‏.‏ قَالَ مَالِكٌ فِي الْمُخَيَّرَةِ إِذَا خَيَّرَهَا زَوْجُهَا فَاخْتَارَتْ نَفْسَهَا فَقَدْ طَلُقَتْ ثَلاَثًا وَإِنْ قَالَ زَوْجُهَا لَمْ أُخَيِّرْكِ إِلاَّ وَاحِدَةً فَلَيْسَ لَهُ ذَلِكَ ‏.‏ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُهُ ‏.‏ قَالَ مَالِكٌ وَإِنْ خَيَّرَهَا فَقَالَتْ قَدْ قَبِلْتُ وَاحِدَةً وَقَالَ لَمْ أُرِدْ هَذَا وَإِنَّمَا خَيَّرْتُكِ فِي الثَّلاَثِ جَمِيعًا أَنَّهَا إِنْ لَمْ تَقْبَلْ إِلاَّ وَاحِدَةً أَقَامَتْ عِنْدَهُ عَلَى نِكَاحِهَا وَلَمْ يَكُنْ ذَلِكَ فِرَاقًا إِنْ شَاءَ اللَّهُ تَعَالَى ‏.‏\hadithno{1183}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik said that if a slave-girl, who was the wife of a slave, was set free before he had consummated the marriage, and she chose herself, then she had no bride-price and it was a pronouncement of divorce. That was what was done among them. Yahya related to me that Malik heard Ibn Shihab say, "When a man gives his wife the right of choice, and she chooses him, that is not divorce." Malik added, "That is the best of what I have heard." Malik said that if a woman who had been given the right of choice by her husband chose herself, she was divorced trebly. If her husband said, "But I only gave her the right of choice in one," he had none of that. That was the best of what he had heard. Malik said, "If the man gives his wife the right of choice and she says, 'I accept one', and he says, 'I did not mean that, I have given the right of choice in all three together,' then if she only accepts one, she remains with him in her marriage, and that is not separation if Allah, the Exalted wills}}
\hadithdefcmd{malik}{1184}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ عَنْ حَبِيبَةَ بِنْتِ سَهْلٍ الأَنْصَارِيِّ، أَنَّهَا كَانَتْ تَحْتَ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الصُّبْحِ فَوَجَدَ حَبِيبَةَ بِنْتَ سَهْلٍ عِنْدَ بَابِهِ فِي الْغَلَسِ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقَالَتْ أَنَا حَبِيبَةُ بِنْتُ سَهْلٍ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ مَا شَأْنُكِ ‏"‏ ‏.‏ قَالَتْ لاَ أَنَا وَلاَ ثَابِتُ بْنُ قَيْسٍ ‏.‏ لِزَوْجِهَا فَلَمَّا جَاءَ زَوْجُهَا ثَابِتُ بْنُ قَيْسٍ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذِهِ حَبِيبَةُ بِنْتُ سَهْلٍ قَدْ ذَكَرَتْ مَا شَاءَ اللَّهُ أَنْ تَذْكُرَ ‏"‏ ‏.‏ فَقَالَتْ حَبِيبَةُ يَا رَسُولَ اللَّهِ كُلُّ مَا أَعْطَانِي عِنْدِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِثَابِتِ بْنِ قَيْسٍ ‏"‏ خُذْ مِنْهَا ‏"‏ ‏.‏ فَأَخَذَ مِنْهَا وَجَلَسَتْ فِي بَيْتِ أَهْلِهَا ‏.‏\hadithno{1184}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related. to me from Malik from Yahya ibn Said that Amra bint Abd ar-Rahman told him from Habiba bint Sahl al-Ansari that she had been the wife of Thabit ibn Qays ibn Shammas. The Messenger of Allah, may Allah bless him and grant him peace, went out for the dawn prayer, and found Habiba bint Sahl at his door in the darkness. The Messenger of Allah, may Allah bless him and grant him peace, said to her, "Who is this?" She said, "I am Habiba bint Sahl, Messenger of Allah." He said, "What do you want?" She said, "That Thabit ibn Qays and I separate." When her husband, Thabit ibn Qays came, the Messenger of Allah, may Allah bless him and grant him peace, said to him, "This is Habiba bint Sahl. She mentioned what Allah willed that she mention." Habiba said, "Messenger of Allah, all that he has given me is with me!" The Messenger of Allah, may Allah bless him and grant him peace, said to Thabit ibn Qays, "Take it from her," and he took it from her, and she stayed in the house of her family}}
\hadithdefcmd{malik}{1185}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ مَوْلاَةٍ، لِصَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ ‏.‏ أَنَّهَا اخْتَلَعَتْ مِنْ زَوْجِهَا بِكُلِّ شَىْءٍ لَهَا فَلَمْ يُنْكِرْ ذَلِكَ عَبْدُ اللَّهِ بْنُ عُمَرَ ‏.‏ قَالَ مَالِكٌ فِي الْمُفْتَدِيَةِ الَّتِي تَفْتَدِي مِنْ زَوْجِهَا أَنَّهُ إِذَا عُلِمَ أَنَّ زَوْجَهَا أَضَرَّ بِهَا وَضَيَّقَ عَلَيْهَا وَعُلِمَ أَنَّهُ ظَالِمٌ لَهَا مَضَى الطَّلاَقُ وَرَدَّ عَلَيْهَا مَالَهَا ‏.‏ قَالَ فَهَذَا الَّذِي كُنْتُ أَسْمَعُ وَالَّذِي عَلَيْهِ أَمْرُ النَّاسِ عِنْدَنَا ‏.‏ قَالَ مَالِكٌ لاَ بَأْسَ بِأَنْ تَفْتَدِيَ الْمَرْأَةُ مِنْ زَوْجِهَا بِأَكْثَرَ مِمَّا أَعْطَاهَا ‏.‏\hadithno{1185}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Nafi from a mawla of Safiyya bint Abi Ubayd that she gave all that she possessed to her husband as compensation for her divorce from him, and Abdullah ibn Umar did not disapprove of that. Malik said that divorce was ratified for a woman who ransomed herself from her husband, when it was known that her husband was detrimental to her and was oppressive for her, and it was known that he wronged her, and he had to return her property to her. Malik added, "This is what I have heard, and it is what is done among us." Malik said, "There is no harm if a woman ransoms herself from her husband for more than he gave her}}
\hadithdefcmd{malik}{1186}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ رُبَيِّعَ بِنْتَ مُعَوِّذِ بْنِ عَفْرَاءَ، جَاءَتْ هِيَ وَعَمُّهَا إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ فَأَخْبَرَتْهُ أَنَّهَا اخْتَلَعَتْ مِنْ زَوْجِهَا فِي زَمَانِ عُثْمَانَ بْنِ عَفَّانَ فَبَلَغَ ذَلِكَ عُثْمَانَ بْنَ عَفَّانَ فَلَمْ يُنْكِرْهُ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ عِدَّتُهَا عِدَّةُ الْمُطَلَّقَةِ ‏.‏\hadithno{1186}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Rubayyi bint Muawwidh ibn Afra came with her paternal uncle to Abdullah ibn Umar and told him that she had divorced her husband for a compensation in the time of Uthman ibn Affan, and he heard about it and did not disapprove. Abdullah ibn Umar said, "Her idda is the idda of a divorced woman}}
\hadithdefcmd{malik}{1187}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، وَابْنَ، شِهَابٍ كَانُوا يَقُولُونَ عِدَّةُ الْمُخْتَلِعَةِ مِثْلُ عِدَّةِ الْمُطَلَّقَةِ ثَلاَثَةُ قُرُوءٍ ‏.‏ قَالَ مَالِكٌ فِي الْمُفْتَدِيَةِ إِنَّهَا لاَ تَرْجِعُ إِلَى زَوْجِهَا إِلاَّ بِنِكَاحٍ جَدِيدٍ فَإِنْ هُوَ نَكَحَهَا فَفَارَقَهَا قَبْلَ أَنْ يَمَسَّهَا لَمْ يَكُنْ لَهُ عَلَيْهَا عِدَّةٌ مِنَ الطَّلاَقِ الآخَرِ وَتَبْنِي عَلَى عِدَّتِهَا الأُولَى ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحْسَنُ مَا سَمِعْتُ فِي ذَلِكَ ‏.‏ قَالَ مَالِكٌ إِذَا افْتَدَتِ الْمَرْأَةُ مِنْ زَوْجِهَا بِشَىْءٍ عَلَى أَنْ يُطَلِّقَهَا فَطَلَّقَهَا طَلاَقًا مُتَتَابِعًا نَسَقًا فَذَلِكَ ثَابِتٌ عَلَيْهِ فَإِنْ كَانَ بَيْنَ ذَلِكَ صُمَاتٌ فَمَا أَتْبَعَهُ بَعْدَ الصُّمَاتِ فَلَيْسَ بِشَىْءٍ ‏.‏\hadithno{1187}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Sulayman ibn Yasar and Ibn Shihab all said that a woman who divorced for a compensation had the same idda as a divorced woman - three periods. Malik said that a woman who ransomed herself could not return to her husband except by a new marriage. If someone married her and then separated from her before he had intercourse with her, there was no idda against her from the recent marriage, and she rested on her first idda. Malik said, "That is the best that I have heard on the matter." Malik said, "If, when a woman offers to compensate her husband, he divorces her straightaway, then that compensation is confirmed for him. If he makes no response, and then at a later date, does divorce her, he is not entitled to that compensation}}
\hadithdefcmd{malik}{1188}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ عُوَيْمِرًا الْعَجْلاَنِيَّ جَاءَ إِلَى عَاصِمِ بْنِ عَدِيٍّ الأَنْصَارِيِّ فَقَالَ لَهُ يَا عَاصِمُ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ سَلْ لِي يَا عَاصِمُ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَسَأَلَ عَاصِمٌ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا حَتَّى كَبُرَ عَلَى عَاصِمٍ مَا سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَجَعَ عَاصِمٌ إِلَى أَهْلِهِ جَاءَهُ عُوَيْمِرٌ فَقَالَ يَا عَاصِمُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمٌ لِعُوَيْمِرٍ لَمْ تَأْتِنِي بِخَيْرٍ قَدْ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْأَلَةَ الَّتِي سَأَلْتُهُ عَنْهَا ‏.‏ فَقَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَهُ عَنْهَا ‏.‏ فَأَقْبَلَ عُوَيْمِرٌ حَتَّى أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَسْطَ النَّاسِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ أُنْزِلَ فِيكَ وَفِي صَاحِبَتِكَ فَاذْهَبْ فَأْتِ بِهَا ‏"‏ ‏.‏ قَالَ سَهْلٌ فَتَلاَعَنَا وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَرَغَا مِنْ تَلاَعُنِهِمَا قَالَ عُوَيْمِرٌ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا ‏.‏ فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ ‏.‏ وَقَالَ مَالِكٌ قَالَ ابْنُ شِهَابٍ فَكَانَتْ تِلْكَ بَعْدُ سُنَّةَ الْمُتَلاَعِنَيْنِ ‏.‏\hadithno{1188}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Sahl ibn Sad as-Saidi told him that Uwaymir al-Ajlani came to Asim ibn Adi al- Ansari and said to him, "Asim! What do you think a man who finds another man with his wife should do? Should he kill him and then be killed himself, or what should .he do? Asim! ask the Messenger of Allah, may Allah bless him and grant him peace, about that for me." Asim asked the Messenger of Allah, may Allah bless him and grant him peace, about it. The Messenger of Allah, may Allah bless him and grant him peace, was revolted by the questions and reproved them until what he heard from the Messenger of Allah, may Allah bless him and grant him peace. was intolerable for Asim. When Asim returned to his people, Uwaymir came to him and said, " Asim! what did the Messenger of Allah, may Allah bless him and grant him peace, say to you?" Asim said to Uwaymir, "You didn't bring me any good. The Messenger of Allah, may Allah bless him and grant him peace, was revolted by the question which I asked him." Uwaymir said, "By Allah! I will not stop until I ask him about it!" Uwaymir stood up and went to the Messenger of Allah, may Allah bless him and grant him peace, in the middle of the people and said, "Messenger of Allah! What do you think a man who finds another man with his wife should do? Should he kill him and then be killed himself, or what should he do?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Something has been sent down about you and your wife, so go and bring her." Sahl continued, "They mutually cursed one another in the presence of the Messenger, may Allah bless him and grant him peace, and I was present with the people. When they finished cursing each other, Uwaymir said, 'I shall have lied about her, Messenger of Allah, if I keep her,' and pronounced the divorce three times before the Messenger of Allah, may Allah bless him and grant him peace, ordered him to do it." Malik said that Ibn Shihab said, "That was how the sunna of a couple mutually cursing each other was established (lian)}}
\hadithdefcmd{malik}{1189}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، لاَعَنَ امْرَأَتَهُ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَانْتَفَلَ مِنْ وَلَدِهَا فَفَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا وَأَلْحَقَ الْوَلَدَ بِالْمَرْأَةِ ‏.‏\hadithno{1189}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafic from Abdullah ibn Umar that a man cursed his wife in the time of the Messenger of Allah, may Allah bless him and grant him peace, and disowned her child. The Messenger of Allah, may Allah bless him and grant him peace, separated them and gave the child to the woman. Malik said, "Allah the Blessed, the Exalted, said, 'The testimony of men who accuse their wives but do not have any witnesses except themselves is to testify by Allah four times that he is being truthful, and a fifth time, that the curse of Allah will be upon him, if he should be a liar. She will avoid punishment if she testifies by Allah four times that he is a liar, and a fifth time, that the wrath of Allah shall be upon her, if he should be telling the truth. ' "(Sura 24 ayat 6). Malik said, "The sunna with us is that those who curse each other are never to be remarried. If the man calls himself a liar, (i.e. takes back his accusation), he is flogged with the hadd-punishment, and the child is given to him, and his wife can never return to him. There is no doubt or dispute about this sunna among us. " Malik said, "If a man separates from his wife by an irrevocable divorce by which he cannot return to her, and then he denies the paternity of the child she is carrying, whilst she claims that he is the father, and it is possible by the timing, that he be so, he must curse her, and the child is not recognised as his." Malik said, "That is what is done among us, and it is what I have heard from the people of knowledge." Malik said that a man who accused his wife after he had divorced her trebly while she was pregnant, and he had at first accepted being the father but then claimed that he had seen her committing adultery before he separated from her, was flogged with the hadd-punishment, and did not curse her. If he denied the paternity of her child after he had divorced her trebly, and he had not previously accepted it, then he cursed her. Malik said, "This is what I have heard." Malik said, "The slave is in the same position as the free man as regards making accusations and invoking mutual curses (lian). He acts in the lian as the free man acts although there is no hadd applied for slandering a female-slave." Malik said, "The muslim slave-girl and the christian and jewish free woman also do lian when a free muslim marries one of them and has intercourse with her. That is because Allah - may He be blessed and Exalted, said in His Book, 'As for those who accuse their wives,' and they are their wives. This is what is done among us. Malik said that a man who did the lian with his wife, and then stopped and called himself a liar after one or two oaths and he had not cursed himself in the fifth one, had to be flogged with the hadd-punishment, but they did not have to be separated. Malik said that if a man divorced his wife and then after three months the woman said, "I am pregnant," and he denied paternity, then he had to do lian. Malik said that the husband of a female slave who pronounced the lian on her and then bought her, was not to have intercourse with her, even if he owned her. The sunna which had been handed down about a couple who mutually cursed each other in the lian was that they were never to return to each other. Malik said that when a man pronounced the lian against his wife before he had consummated the marriage, she only had half of the bride price}}
\hadithdefcmd{malik}{1190}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، كَانَ يَقُولُ فِي وَلَدِ الْمُلاَعَنَةِ وَوَلَدِ الزِّنَا أَنَّهُ إِذَا مَاتَ وَرِثَتْهُ أُمُّهُ حَقَّهَا فِي كِتَابِ اللَّهِ تَعَالَى وَإِخْوَتُهُ لأُمِّهِ حُقُوقَهُمْ وَيَرِثُ الْبَقِيَّةَ مَوَالِي أُمِّهِ إِنْ كَانَتْ مَوْلاَةً وَإِنْ كَانَتْ عَرَبِيَّةً وَرِثَتْ حَقَّهَا وَوَرِثَ إِخْوَتُهُ لأُمِّهِ حُقُوقَهُمْ وَكَانَ مَا بَقِيَ لِلْمُسْلِمِينَ ‏.‏ قَالَ مَالِكٌ وَبَلَغَنِي عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، مِثْلُ ذَلِكَ ‏.‏ وَعَلَى ذَلِكَ أَدْرَكْتُ أَهْلَ الْعِلْمِ بِبَلَدِنَا ‏\hadithno{1190}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that `Urwa ibn az-Zubayr said that if the child of the woman against whom li`an had been pronounced or the child of fornication, died, his mother inherited from him her right in the Book of Allah the Exalted, and his maternal half-brothers had their rights. The rest was inherited by the owners of his mother's wala' if she was a freed slave. If she was an ordinary free woman, she inherited her right, his maternal brothers inherited their rights, and the rest went to the Muslims. Malik said,"I heard the same as that from Sulayman ibn Yasar, and it is what I saw the people of knowledge in our city doing}}
\hadithdefcmd{malik}{1192}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ مُحَمَّدِ بْنِ إِيَاسِ بْنِ الْبُكَيْرِ، أَنَّهُ قَالَ طَلَّقَ رَجُلٌ امْرَأَتَهُ ثَلاَثًا قَبْلَ أَنْ يَدْخُلَ بِهَا ثُمَّ بَدَا لَهُ أَنْ يَنْكِحَهَا فَجَاءَ يَسْتَفْتِي فَذَهَبْتُ مَعَهُ أَسْأَلُ لَهُ فَسَأَلَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ وَأَبَا هُرَيْرَةَ عَنْ ذَلِكَ فَقَالاَ لاَ نَرَى أَنْ تَنْكِحَهَا حَتَّى تَنْكِحَ زَوْجًا غَيْرَكَ ‏.‏ قَالَ فَإِنَّمَا طَلاَقِي إِيَّاهَا وَاحِدَةٌ ‏.‏ قَالَ ابْنُ عَبَّاسٍ إِنَّكَ أَرْسَلْتَ مِنْ يَدِكَ مَا كَانَ لَكَ مِنْ فَضْلٍ ‏.‏\hadithno{1192}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Muhammad ibn Abd ar-Rahman ibn Thawban that Muhammad ibn Iyas ibn al-Bukayr said, "A man divorced his wife three times before he had consummated the marriage, and then it seemed good to him to marry her. Therefore, he wanted an opinion, and I went with him to ask Abdullah ibn Abbas and Abu Hurayra on his behalf about it, and they said, 'We do not think that you should marry her until she has married another husband.' He protested that his divorcing her had been only once. Ibn Abbas said, 'You threw away what you had of blessing}}
\hadithdefcmd{malik}{1193}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ الأَنْصَارِيِّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ قَالَ جَاءَ رَجُلٌ يَسْأَلُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ عَنْ رَجُلٍ طَلَّقَ امْرَأَتَهُ ثَلاَثًا قَبْلَ أَنْ يَمَسَّهَا قَالَ عَطَاءٌ فَقُلْتُ إِنَّمَا طَلاَقُ الْبِكْرِ وَاحِدَةٌ ‏.‏ فَقَالَ لِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ إِنَّمَا أَنْتَ قَاصٌّ الْوَاحِدَةُ تُبِينُهَا وَالثَّلاَثَةُ تُحَرِّمُهَا حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏\hadithno{1193}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Bukayr ibn Abdullah al-Ashajj from an-Numan ibn Abi Ayyash al Ansari from Ata ibn Yasar that a man came and asked Abdullah ibn Amr ibn al-As about a man who divorced his wife three times before he had had intercourse with her Ata said, "The divorce of the virgin is one. Abdullah ibn Amr ibn al-As said to me, 'You say one pronouncement separates her and three makes her haram until she has married another husband}}
\hadithdefcmd{malik}{1194}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، أَنَّهُ أَخْبَرَهُ عَنْ مُعَاوِيَةَ بْنِ أَبِي عَيَّاشٍ الأَنْصَارِيِّ، أَنَّهُ كَانَ جَالِسًا مَعَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ وَعَاصِمِ بْنِ عُمَرَ بْنِ الْخَطَّابِ قَالَ فَجَاءَهُمَا مُحَمَّدُ بْنُ إِيَاسِ بْنِ الْبُكَيْرِ فَقَالَ إِنَّ رَجُلاً مِنْ أَهْلِ الْبَادِيَةِ طَلَّقَ امْرَأَتَهُ ثَلاَثًا قَبْلَ أَنْ يَدْخُلَ بِهَا فَمَاذَا تَرَيَانِ فَقَالَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ إِنَّ هَذَا الأَمْرَ مَا لَنَا فِيهِ قَوْلٌ فَاذْهَبْ إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ فَإِنِّي تَرَكْتُهُمَا عِنْدَ عَائِشَةَ فَسَلْهُمَا ثُمَّ ائْتِنَا فَأَخْبِرْنَا ‏.‏ فَذَهَبَ فَسَأَلَهُمَا فَقَالَ ابْنُ عَبَّاسٍ لأَبِي هُرَيْرَةَ أَفْتِهِ يَا أَبَا هُرَيْرَةَ فَقَدْ جَاءَتْكَ مُعْضِلَةٌ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ الْوَاحِدَةُ تُبِينُهَا وَالثَّلاَثَةُ تُحَرِّمُهَا حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ مِثْلَ ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ الأَمْرُ عِنْدَنَا وَالثَّيِّبُ إِذَا مَلَكَهَا الرَّجُلُ فَلَمْ يَدْخُلْ بِهَا إِنَّهَا تَجْرِي مَجْرَى الْبِكْرِ الْوَاحِدَةُ تُبِينُهَا وَالثَّلاَثُ تُحَرِّمُهَا حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏\hadithno{1194}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Bukayr ibn Abdullah al-Ashajj informed him that Muawiya ibn Abi Ayyash al- Ansari told him that he was sitting with Abdullah ibn az-Zubayr and Asim ibn Umar ibn al-Khattab when Muhammad ibn Iyas ibn al-Bukayr came up to them and said, "A man from the desert has divorced his wife three times before consummating the marriage, what do you think?" Abdullah ibn az-Zubayr said "This is something about which we have no statement. Go to Abdullah ibn Abbas and Abu Hurayra. I left them with A'isha. Ask them and then come and tell us." He went and asked them. Ibn Abbas said to Abu Hurayra, "Give an opinion, Abu Hurayra! A difficult one has come to you." Abu Hurayra said, "One pronouncement separates her and three makes her haram until she has married another husband." Ibn Abbas said the like of that. Malik said, "That is what is done among us, and when a man marries a woman who has been married before, and he has not had intercourse with her, she is treated as a virgin - one pronouncement separates her and three make her haram until she has married another husband}}
\hadithdefcmd{malik}{1195}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، - قَالَ وَكَانَ أَعْلَمَهُمْ بِذَلِكَ - وَعَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، طَلَّقَ امْرَأَتَهُ الْبَتَّةَ وَهُوَ مَرِيضٌ فَوَرَّثَهَا عُثْمَانُ بْنُ عَفَّانَ مِنْهُ بَعْدَ انْقِضَاءِ عِدَّتِهَا ‏.‏\hadithno{1195}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Talha ibn Abdullah ibn Awf said, and he knew that better than them, from Abu Salama ibn Abd ar-Rahman ibn Awf that Abd ar-Rahman ibn Awf divorced his wife irrevocably while he was terminally ill, and Uthman ibn Affan made her an heir after the end of her idda}}
\hadithdefcmd{malik}{1196}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنِ الأَعْرَجِ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، وَرَّثَ نِسَاءَ ابْنِ مُكْمِلٍ مِنْهُ وَكَانَ طَلَّقَهُنَّ وَهُوَ مَرِيضٌ ‏.‏\hadithno{1196}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn al-Fadl from al- Araj that Uthman ibn Affan made the wives of ibn Mukmil inherit from him, and he had divorced them while he was terminally ill}}
\hadithdefcmd{malik}{1197}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ رَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ، يَقُولُ بَلَغَنِي أَنَّ امْرَأَةَ، عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ سَأَلَتْهُ أَنْ يُطَلِّقَهَا فَقَالَ إِذَا حِضْتِ ثُمَّ طَهُرْتِ فَآذِنِينِي فَلَمْ تَحِضْ حَتَّى مَرِضَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فَلَمَّا طَهُرَتْ آذَنَتْهُ فَطَلَّقَهَا الْبَتَّةَ أَوْ تَطْلِيقَةً لَمْ يَكُنْ بَقِيَ لَهُ عَلَيْهَا مِنَ الطَّلاَقِ غَيْرُهَا وَعَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ يَوْمَئِذٍ مَرِيضٌ فَوَرَّثَهَا عُثْمَانُ بْنُ عَفَّانَ مِنْهُ بَعْدَ انْقِضَاءِ عِدَّتِهَا ‏.‏\hadithno{1197}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he heard Rabia ibn Abi Abd ar-Rahman say, ''I heard that the wife of Abd ar-Rahman ibn Awf asked him to divorce her. He said, 'When you have menstruated and are pure, then come to me.' She did not menstruate until Abd ar-Rahman ibn Awf was ill. When she was purified, she told him and he divorced her irrevocably or made a pronouncement of divorce which was all that he had left over her Abd arRahman ibn Awf was terminally ill at the time, so Uthman ibn Affan made her one of the heirs after the end of her idda}}
\hadithdefcmd{malik}{1198}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، قَالَ كَانَتْ عِنْدَ جَدِّي حَبَّانَ امْرَأَتَانِ هَاشِمِيَّةٌ وَأَنْصَارِيَّةٌ فَطَلَّقَ الأَنْصَارِيَّةَ وَهِيَ تُرْضِعُ فَمَرَّتْ بِهَا سَنَةٌ ثُمَّ هَلَكَ عَنْهَا وَلَمْ تَحِضْ فَقَالَتْ أَنَا أَرِثُهُ لَمْ أَحِضْ فَاخْتَصَمَتَا إِلَى عُثْمَانَ بْنِ عَفَّانَ فَقَضَى لَهَا بِالْمِيرَاثِ فَلاَمَتِ الْهَاشِمِيَّةُ عُثْمَانَ فَقَالَ هَذَا عَمَلُ ابْنِ عَمِّكِ هُوَ أَشَارَ عَلَيْنَا بِهَذَا يَعْنِي عَلِيَّ بْنَ أَبِي طَالِبٍ ‏.‏\hadithno{1198}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Muhammad ibn Yahya ibn Habban said, "My grandfather Habban had two wives, one from the Hashimites and one from the Ansars. He divorced the Ansariyya while she was nursing, and a year passed and he died and she had still not yet menstruated. She said, 'I inherit from him. I have not menstruated yet.' The wives quarrelled and went to Uthman ibn Affan. He decided that she did inherit, and the Hashimiyya rebuked Uthman. He said, 'This is the practice of the son of your paternal uncle. He pointed this out to us.' He meant Ali ibn Abi Talib}}
\hadithdefcmd{malik}{1199}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ إِذَا طَلَّقَ الرَّجُلُ امْرَأَتَهُ ثَلاَثًا وَهُوَ مَرِيضٌ فَإِنَّهَا تَرِثُهُ ‏.‏ قَالَ مَالِكٌ وَإِنْ طَلَّقَهَا وَهُوَ مَرِيضٌ قَبْلَ أَنْ يَدْخُلَ بِهَا فَلَهَا نِصْفُ الصَّدَاقِ وَلَهَا الْمِيرَاثُ وَلاَ عِدَّةَ عَلَيْهَا وَإِنْ دَخَلَ بِهَا ثُمَّ طَلَّقَهَا فَلَهَا الْمَهْرُ كُلُّهُ وَالْمِيرَاثُ الْبِكْرُ وَالثَّيِّبُ فِي هَذَا عِنْدَنَا سَوَاءٌ ‏.‏\hadithno{1199}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard Ibn Shihab say, "When a man who is terminally ill divorces his wife three times, she inherits from him." Malik said, "If he divorces her while he is terminally ill before he has consummated the marriage, she has half of the bride-price and inherits, and she does not have to do an idda. If he consummated the marriage, she has all the dowry and inherits. The virgin and the previously married woman are the same in this situation according to us}}
\hadithdefcmd{malik}{1200}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، طَلَّقَ امْرَأَةً لَهُ فَمَتَّعَ بِوَلِيدَةٍ ‏.‏\hadithno{1200}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abd ar- Rahman ibn Awf divorced his wife, and gave her compensation in the form of a slave-girl}}
\hadithdefcmd{malik}{1201}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ لِكُلِّ مُطَلَّقَةٍ مُتْعَةٌ إِلاَّ الَّتِي تُطَلَّقُ وَقَدْ فُرِضَ لَهَا صَدَاقٌ وَلَمْ تُمَسَّ فَحَسْبُهَا نِصْفُ مَا فُرِضَ لَهَا ‏.‏\hadithno{1201}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "Every divorced woman has compensation except for the one who is divorced and is allocated a bride-price and has not been touched. She has half of what was allocated to her}}
\hadithdefcmd{malik}{1202}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ لِكُلِّ مُطَلَّقَةٍ مُتْعَةٌ ‏.‏ قَالَ مَالِكٌ وَبَلَغَنِي عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، مِثْلُ ذَلِكَ ‏.‏ قَالَ مَالِكٌ لَيْسَ لِلْمُتْعَةِ عِنْدَنَا حَدٌّ مَعْرُوفٌ فِي قَلِيلِهَا وَلاَ كَثِيرِهَا ‏\hadithno{1202}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "Every divorced woman has compensation." Malik said, "I have also heard the same as that from al-Qasim ibn Muhammad." Malik said, "There is no fixed limit among us as to how small or large the compensation is}}
\hadithdefcmd{malik}{1204}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ نُفَيْعًا، مُكَاتَبًا كَانَ لأُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَوْ عَبْدًا لَهَا كَانَتْ تَحْتَهُ امْرَأَةٌ حُرَّةٌ فَطَلَّقَهَا اثْنَتَيْنِ ثُمَّ أَرَادَ أَنْ يُرَاجِعَهَا فَأَمَرَهُ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم أَنْ يَأْتِيَ عُثْمَانَ بْنَ عَفَّانَ فَيَسْأَلَهُ عَنْ ذَلِكَ فَلَقِيَهُ عِنْدَ الدَّرَجِ آخِذًا بِيَدِ زَيْدِ بْنِ ثَابِتٍ فَسَأَلَهُمَا فَابْتَدَرَاهُ جَمِيعًا فَقَالاَ حَرُمَتْ عَلَيْكَ حَرُمَتْ عَلَيْكَ ‏.‏\hadithno{1204}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from Sulayman ibn Yasar that Nufay, a mukatab of Umm Salama the wife of the Prophet, may Allah bless him and grant him peace, or her slave, had a free woman as a wife. He divorced her twice, and then he wanted to return to her. The wives of the Prophet, may Allah bless him and grant him peace, ordered him to go to Uthman ibn Affan to ask him about it. He found him at ad-Daraj with Zayd ibn Thabit. He asked them, and they both anticipated him and said, "She is haram for you. She is haram for you}}
\hadithdefcmd{malik}{1205}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ نُفَيْعًا، مُكَاتَبًا كَانَ لأُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم طَلَّقَ امْرَأَةً حُرَّةً تَطْلِيقَتَيْنِ فَاسْتَفْتَى عُثْمَانَ بْنَ عَفَّانَ فَقَالَ حَرُمَتْ عَلَيْكَ ‏.‏\hadithno{1205}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab that Nufay, a mukatab of Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, divorced his free wife twice, so he asked Uthman ibn Affan for an opinion, and he said, "She is haram for you}}
\hadithdefcmd{malik}{1206}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، أَنَّ نُفَيْعًا، مُكَاتَبًا كَانَ لأُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم اسْتَفْتَى زَيْدَ بْنَ ثَابِتٍ فَقَالَ إِنِّي طَلَّقْتُ امْرَأَةً حُرَّةً تَطْلِيقَتَيْنِ ‏.‏ فَقَالَ زَيْدُ بْنُ ثَابِتٍ حَرُمَتْ عَلَيْكَ ‏.‏\hadithno{1206}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abdu Rabbih ibn Said from Muhammad ibn Ibrahim ibn al-Harith at-Taymi that Nufay, a mukatab of Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, asked Zayd ibn Thabit for an opinion. He said, "I have divorced my free wife twice." Zayd ibn Thabit said, "She is haram for you}}
\hadithdefcmd{malik}{1207}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا طَلَّقَ الْعَبْدُ امْرَأَتَهُ تَطْلِيقَتَيْنِ فَقَدْ حَرُمَتْ عَلَيْهِ حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ حُرَّةً كَانَتْ أَوْ أَمَةً وَعِدَّةُ الْحُرَّةِ ثَلاَثُ حِيَضٍ وَعِدَّةُ الأَمَةِ حَيْضَتَانِ ‏.‏\hadithno{1207}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "When the slave divorces his wife twice, she is haram for him until she has married another husband, whether she is free or a slave. The idda of a free woman is three menstrual periods, and the idda of a slave-girl is two periods}}
\hadithdefcmd{malik}{1208}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَنْ أَذِنَ لِعَبْدِهِ أَنْ يَنْكِحَ فَالطَّلاَقُ بِيَدِ الْعَبْدِ لَيْسَ بِيَدِ غَيْرِهِ مِنْ طَلاَقِهِ شَىْءٌ فَأَمَّا أَنْ يَأْخُذَ الرَّجُلُ أَمَةَ غُلاَمِهِ أَوْ أَمَةَ وَلِيدَتِهِ فَلاَ جُنَاحَ عَلَيْهِ ‏.‏\hadithno{1208}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "If a man gives his slave permission to marry, the divorce is in the hand of the slave, and nobody else has any power over his divorce. Nothing is held against a man who takes the slave-girl of his male slave or the slave-girl of his female-slave}}
\hadithdefcmd{malik}{1209}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ أَيُّمَا امْرَأَةٍ فَقَدَتْ زَوْجَهَا فَلَمْ تَدْرِ أَيْنَ هُوَ فَإِنَّهَا تَنْتَظِرُ أَرْبَعَ سِنِينَ ثُمَّ تَعْتَدُّ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ثُمَّ تَحِلُّ ‏.‏ قَالَ مَالِكٌ وَإِنْ تَزَوَّجَتْ بَعْدَ انْقِضَاءِ عِدَّتِهَا فَدَخَلَ بِهَا زَوْجُهَا أَوْ لَمْ يَدْخُلْ بِهَا فَلاَ سَبِيلَ لِزَوْجِهَا الأَوَّلِ إِلَيْهَا ‏.‏ قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ عِنْدَنَا وَإِنْ أَدْرَكَهَا زَوْجُهَا قَبْلَ أَنْ تَتَزَوَّجَ فَهُوَ أَحَقُّ بِهَا ‏.‏ قَالَ مَالِكٌ وَأَدْرَكْتُ النَّاسَ يُنْكِرُونَ الَّذِي قَالَ بَعْضُ النَّاسِ عَلَى عُمَرَ بْنِ الْخَطَّابِ أَنَّهُ قَالَ يُخَيَّرُ زَوْجُهَا الأَوَّلُ إِذَا جَاءَ فِي صَدَاقِهَا أَوْ فِي امْرَأَتِهِ ‏.‏\hadithno{1209}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik said, "Neither a free man nor a slave who divorces a slave- girl nor a slave who divorces a free woman, in an irrevocable divorce, is obliged to pay maintenance even if she is pregnant, and he cannot return to her." Malik said, "A free man is not obliged to pay for the suckling of his son when he is a slave of other people, nor is a slave obliged to spend his money for what his master owns except with the permission of his master}}
\hadithdefcmd{malik}{1210}{قَالَ مَالِكٌ وَبَلَغَنِي أَنَّ عُمَرَ بْنَ الْخَطَّابِ قَالَ فِي الْمَرْأَةِ يُطَلِّقُهَا زَوْجُهَا وَهُوَ غَائِبٌ عَنْهَا ثُمَّ يُرَاجِعُهَا فَلاَ يَبْلُغُهَا رَجْعَتُهُ وَقَدْ بَلَغَهَا طَلاَقُهُ إِيَّاهَا فَتَزَوَّجَتْ أَنَّهُ إِنْ دَخَلَ بِهَا زَوْجُهَا الآخَرُ أَوْ لَمْ يَدْخُلْ بِهَا فَلاَ سَبِيلَ لِزَوْجِهَا الأَوَّلِ الَّذِي كَانَ طَلَّقَهَا إِلَيْهَا ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي هَذَا وَفِي الْمَفْقُودِ ‏.‏\hadithno{1210}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said ibn al-Musayyab that Umar ibn al-Khattab said, "The woman who loses her husband and does not know where he is, waits for four years, then she does idda for four months, and then she is free to marry." Malik said, "If she marries after her idda is over, regardless of whether the new husband has consummated the marriage or not, her first husband has no means of access to her." Malik said, "That is what is done among us and if her husband reaches her before she has remarried, he is more entitled to her." Malik said that he had seen people disapproving of someone who said that one of the people (of knowledge) attributed to Umar ibn al-Khattab that he said, "Her first husband chooses when he comes either her bride-price or his wife." Malik said, "I have heard that Umar ibn al-Khattab, speaking about a woman whose husband divorced her while he was absent from her, and then he took her back and the news of his taking her back had not reached her, while the news of his divorcing her had, and so she had married again, said, 'Her first husband who divorced her has no means of access to her whether or not the new husband has consummated the marriage.' " Malik said, "This is what I like the best of what I heard about the missing man}}
\hadithdefcmd{malik}{1211}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ بْنُ الْخَطَّابِ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ يُمْسِكْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ ثُمَّ تَطْهُرَ ثُمَّ إِنْ شَاءَ أَمْسَكَ بَعْدُ وَإِنْ شَاءَ طَلَّقَ قَبْلَ أَنْ يَمَسَّ فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ أَنْ يُطَلَّقَ لَهَا النِّسَاءُ ‏"‏ ‏.‏\hadithno{1211}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar divorced his wife while she was menstruating in the time of the Messenger of Allah, may Allah bless him and grant him peace, Umar ibn al-Khattab asked the Messenger of Allah, may Allah bless him and grant him peace, about it. The Messenger of Allah, may Allah bless him and grant him peace, said, "Go and tell him to take her back and keep her until she is purified and then has a period and then is purified. Then if he wishes, he an keep her, and if he wishes he should divorce her before he has intercourse with her. That is the idda which Allah has commanded for women who are divorced}}
\hadithdefcmd{malik}{1212}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا انْتَقَلَتْ حَفْصَةَ بِنْتَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ حِينَ دَخَلَتْ فِي الدَّمِ مِنَ الْحَيْضَةِ الثَّالِثَةِ ‏.‏ قَالَ ابْنُ شِهَابٍ فَذُكِرَ ذَلِكَ لِعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ فَقَالَتْ صَدَقَ عُرْوَةُ وَقَدْ جَادَلَهَا فِي ذَلِكَ نَاسٌ فَقَالُوا إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏ثَلاَثَةَ قُرُوءٍ‏\}‏ فَقَالَتْ عَائِشَةُ صَدَقْتُمْ تَدْرُونَ مَا الأَقْرَاءُ إِنَّمَا الأَقْرَاءُ الأَطْهَارُ ‏.‏\hadithno{1212}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr from A'isha, umm al-muminin, that she took Hafsa ibn Abd ar- Rahman ibn Abi Bakr as-Siddiq into her house when she had entered the third period of her idda. Ibn Shihab said, "That was mentioned to Amra bint Abd ar-Rahman, and she said that Urwa had spoken the truth and people had argued with A'isha about it. They said that Allah, the Blessed, the Exalted, said in His Book, 'Three quru.' A'isha said, 'You spoke the truth. Do you know what quru are? Quru are times of becoming pure after menstruation}}
\hadithdefcmd{malik}{1213}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ سَمِعْتُ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، يَقُولُ مَا أَدْرَكْتُ أَحَدًا مِنْ فُقَهَائِنَا إِلاَّ وَهُوَ يَقُولُ هَذَا ‏.‏ يُرِيدُ قَوْلَ عَائِشَةَ ‏.‏\hadithno{1213}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said that he heard Abu Bakr ibn Abd ar-Rahman say, "I have never seen any of our fuqaha who did not say that this was what the statement of A'isha meant}}
\hadithdefcmd{malik}{1214}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَزَيْدِ بْنِ أَسْلَمَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ الأَحْوَصَ، هَلَكَ بِالشَّامِ حِينَ دَخَلَتِ امْرَأَتُهُ فِي الدَّمِ مِنَ الْحَيْضَةِ الثَّالِثَةِ وَقَدْ كَانَ طَلَّقَهَا فَكَتَبَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ إِلَى زَيْدِ بْنِ ثَابِتٍ يَسْأَلُهُ عَنْ ذَلِكَ فَكَتَبَ إِلَيْهِ زَيْدٌ إِنَّهَا إِذَا دَخَلَتْ فِي الدَّمِ مِنَ الْحَيْضَةِ الثَّالِثَةِ فَقَدْ بَرِئَتْ مِنْهُ وَبَرِئَ مِنْهَا وَلاَ تَرِثُهُ وَلاَ يَرِثُهَا ‏.‏\hadithno{1214}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi and Zayd ibn Aslam from Sulayman ibn Yasar that al-Ahwas died in Syria when his wife had begun her third menstrual period after he had divorced her. Muawiya ibn Abi Sufyan wrote and asked Zayd ibn Thabit about that. Zayd wrote to him, "When she began her third period, she was free from him and he was free from her, and he does not inherit from her nor she from him}}
\hadithdefcmd{malik}{1215}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، وَسَالِمِ بْنِ عَبْدِ اللَّهِ، وَأَبِي، بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ وَسُلَيْمَانَ بْنِ يَسَارٍ وَابْنِ شِهَابٍ أَنَّهُمْ كَانُوا يَقُولُونَ إِذَا دَخَلَتِ الْمُطَلَّقَةُ فِي الدَّمِ مِنَ الْحَيْضَةِ الثَّالِثَةِ فَقَدْ بَانَتْ مِنْ زَوْجِهَا وَلاَ مِيرَاثَ بَيْنَهُمَا وَلاَ رَجْعَةَ لَهُ عَلَيْهَا ‏.‏\hadithno{1215}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abu Bakr ibn Abd ar-Rahman and Sulayman ibn Yasar and Ibn Shihab used to say, "When the divorced woman enters the beginning of her third period, she is clearly separated from her husband and there is no inheritance between them and he has no access to her}}
\hadithdefcmd{malik}{1216}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ إِذَا طَلَّقَ الرَّجُلُ امْرَأَتَهُ فَدَخَلَتْ فِي الدَّمِ مِنَ الْحَيْضَةِ الثَّالِثَةِ فَقَدْ بَرِئَتْ مِنْهُ وَبَرِئَ مِنْهَا ‏.‏ قَالَ مَالِكٌ وَهُوَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1216}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "When a man divorces his wife and she begins her third period, she is free from him and he is free from her." Malik said, "This is how things are done among us}}
\hadithdefcmd{malik}{1217}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْفُضَيْلِ بْنِ أَبِي عَبْدِ اللَّهِ، مَوْلَى الْمَهْرِيِّ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، كَانَا يَقُولاَنِ إِذَا طُلِّقَتِ الْمَرْأَةُ فَدَخَلَتْ فِي الدَّمِ مِنَ الْحَيْضَةِ الثَّالِثَةِ فَقَدْ بَانَتْ مِنْهُ وَحَلَّتْ ‏.‏\hadithno{1217}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from al-Fudayl ibn Abi Abdullah, the mawla of al-Mahri that al-Qasim ibn Muhammad and Salim ibn Abdullah said, "When a woman is divorced and begins her third period, she is clearly separated from him and is free to marry again}}
\hadithdefcmd{malik}{1218}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَابْنِ، شِهَابٍ وَسُلَيْمَانَ بْنِ يَسَارٍ أَنَّهُمْ كَانُوا يَقُولُونَ عِدَّةُ الْمُخْتَلِعَةِ ثَلاَثَةُ قُرُوءٍ ‏.‏\hadithno{1218}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Ibn Shihab and Sulayman ibn Yasar all said, "The idda of the woman with a khul divorce is three periods}}
\hadithdefcmd{malik}{1219}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ عِدَّةُ الْمُطَلَّقَةِ الأَقْرَاءُ وَإِنْ تَبَاعَدَتْ ‏.‏\hadithno{1219}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard Ibn Shihab say, "The idda of the divorced woman is reckoned by the menstrual cycles even if she is estranged ." (The reason the idda is normally reckoned by the menstrual cycle is to see whether the woman is pregnant or not)}}
\hadithdefcmd{malik}{1220}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ أَنَّ امْرَأَتَهُ، سَأَلَتْهُ الطَّلاَقَ فَقَالَ لَهَا إِذَا حِضْتِ فَآذِنِينِي ‏.‏ فَلَمَّا حَاضَتْ آذَنَتْهُ فَقَالَ إِذَا طَهُرْتِ فَآذِنِينِي فَلَمَّا\hadithno{1220}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from a man of the Ansar that his wife asked him for a divorce, and he said to her, "When you have had your period, then tell me." When she had her period, she told him. He said, "When you are purified then tell me." When she was purified, she told him and he divorced her. Malik said, "This is the best of what I have heard about it}}
\hadithdefcmd{malik}{1221}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، وَسُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُ سَمِعَهُمَا يَذْكُرَانِ، أَنَّ يَحْيَى بْنَ سَعِيدِ بْنِ الْعَاصِ، طَلَّقَ ابْنَةَ عَبْدِ الرَّحْمَنِ بْنِ الْحَكَمِ الْبَتَّةَ فَانْتَقَلَهَا عَبْدُ الرَّحْمَنِ بْنُ الْحَكَمِ فَأَرْسَلَتْ عَائِشَةُ أُمُّ الْمُؤْمِنِينَ إِلَى مَرْوَانَ بْنِ الْحَكَمِ وَهُوَ يَوْمَئِذٍ أَمِيرُ الْمَدِينَةِ فَقَالَتِ اتَّقِ اللَّهَ وَارْدُدِ الْمَرْأَةَ إِلَى بَيْتِهَا ‏.‏ فَقَالَ مَرْوَانُ فِي حَدِيثِ سُلَيْمَانَ إِنَّ عَبْدَ الرَّحْمَنِ غَلَبَنِي وَقَالَ مَرْوَانُ فِي حَدِيثِ الْقَاسِمِ أَوَمَا بَلَغَكَ شَأْنُ فَاطِمَةَ بِنْتِ قَيْسٍ فَقَالَتْ عَائِشَةُ لاَ يَضُرُّكَ أَنْ لاَ تَذْكُرَ حَدِيثَ فَاطِمَةَ ‏.‏ فَقَالَ مَرْوَانُ إِنْ كَانَ بِكِ الشَّرُّ فَحَسْبُكِ مَا بَيْنَ هَذَيْنِ مِنَ الشَّرِّ ‏.‏\hadithno{1221}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik thal Yahya ibn Said heard al-Qasim ibn Muhammad and Sulayman ibn Yasar both mention that Yahya ibn Said ibn al-As divorced the daughter of Abd ar-Rahman ibn al-Hakam irrevocably, so Abd ar-Rahman ibn al-Hakam took her away A'isha umm al-muminin sent to Marwan ibn al-Hakam who was the Amir of al-Madina at that time. She said, "Fear Allah and make him return the woman to her house." Marwan said in what Sulayman related, ''Abd ar-Rahman has the upper hand over me." Marwan said in what al-Qasim related, "Hasn't the affair of Fatima bint Qays reached you?" A'isha said, "You are forced to mention the story of Fatima " Marwan said, "If you know that evil, whatever evil there was between those two is enough for you." (See hadith)}}
\hadithdefcmd{malik}{1222}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ بِنْتَ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، كَانَتْ تَحْتَ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ بْنِ عَفَّانَ فَطَلَّقَهَا الْبَتَّةَ فَانْتَقَلَتْ فَأَنْكَرَ ذَلِكَ عَلَيْهَا عَبْدُ اللَّهِ بْنُ عُمَرَ ‏.‏\hadithno{1222}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that the daughter of Said ibn Zayd ibn Amr ibn Nufayl was the wife of Abdullah ibn Umar ibn Uthman ibn Affan, and he divorced her irrevocably and she moved out. Abdullah ibn Umar rebuked her for that}}
\hadithdefcmd{malik}{1223}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، طَلَّقَ امْرَأَةً لَهُ فِي مَسْكَنِ حَفْصَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَكَانَ طَرِيقَهُ إِلَى الْمَسْجِدِ فَكَانَ يَسْلُكُ الطَّرِيقَ الأُخْرَى مِنْ أَدْبَارِ الْبُيُوتِ كَرَاهِيَةَ أَنْ يَسْتَأْذِنَ عَلَيْهَا حَتَّى رَاجَعَهَا ‏.‏\hadithno{1223}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar divorced one of his wives in the house of Hafsa, the wife of the Prophet, may Allah bless him and grant him peace, while he was on the way to the mosque. He went another route from behind the houses being averse to ask permission to enter until he returned to her}}
\hadithdefcmd{malik}{1224}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، سُئِلَ عَنِ الْمَرْأَةِ، يُطَلِّقُهَا زَوْجُهَا وَهِيَ فِي بَيْتٍ بِكِرَاءٍ عَلَى مَنِ الْكِرَاءُ فَقَالَ سَعِيدُ بْنُ الْمُسَيَّبِ عَلَى زَوْجِهَا ‏.‏ قَالَ فَإِنْ لَمْ يَكُنْ عِنْدَ زَوْجِهَا قَالَ فَعَلَيْهَا ‏.‏ قَالَ فَإِنْ لَمْ يَكُنْ عِنْدَهَا قَالَ فَعَلَى الأَمِيرِ ‏.‏\hadithno{1224}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab was asked who was obliged to pay the rent for a woman whose husband divorced her while she was in a leased house. Said ibn al-Musayyab said, "Her husband is obliged to pay it." Someone asked, "what if her husband does not have it?" He said, "Then she must pay it." Someone asked, "And if she does not have it?" He said, "Then the Amir must pay it}}
\hadithdefcmd{malik}{1225}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصٍ، طَلَّقَهَا الْبَتَّةَ وَهُوَ غَائِبٌ بِالشَّامِ فَأَرْسَلَ إِلَيْهَا وَكِيلُهُ بِشَعِيرٍ فَسَخِطَتْهُ فَقَالَ وَاللَّهِ مَا لَكِ عَلَيْنَا مِنْ شَىْءٍ ‏.‏ فَجَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَقَالَ ‏"‏ لَيْسَ لَكِ عَلَيْهِ نَفَقَةٌ ‏"‏ ‏.‏ وَأَمَرَهَا أَنْ تَعْتَدَّ فِي بَيْتِ أُمِّ شَرِيكٍ ثُمَّ قَالَ ‏"‏ تِلْكَ امْرَأَةٌ يَغْشَاهَا أَصْحَابِي اعْتَدِّي عِنْدَ عَبْدِ اللَّهِ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ رَجُلٌ أَعْمَى تَضَعِينَ ثِيَابَكِ عِنْدَهُ فَإِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا حَلَلْتُ ذَكَرْتُ لَهُ أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ وَأَبَا جَهْمِ بْنَ هِشَامٍ خَطَبَانِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا أَبُو جَهْمٍ فَلاَ يَضَعُ عَصَاهُ عَنْ عَاتِقِهِ وَأَمَّا مُعَاوِيَةُ فَصُعْلُوكٌ لاَ مَالَ لَهُ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ قَالَتْ فَكَرِهْتُهُ ثُمَّ قَالَ ‏"‏ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ فَنَكَحْتُهُ فَجَعَلَ اللَّهُ فِي ذَلِكَ خَيْرًا وَاغْتَبَطْتُ بِهِ ‏.‏\hadithno{1225}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Yazid, the mawla of al-Aswad ibn Sufyan from Abu Salama ibn Abd ar-Rahman ibn Awf from Fatima bint Qays that Abu Amr ibn Hafs divorced her absolutely while he was away in Syria. His agent sent her some barley and she was displeased with it, saying, "By Allah, I don't expect anything from you." She went to the Messenger of Allah, may Allah bless him and grant him peace, and mentioned it to him. He said, "You have no maintenance." He then ordered her to spend her idda in the house of Umm Sharik. Then he said, "This is a woman whom my companions visit. Spend the idda in the house of Ibn Umm Maktum. He is a blind man and you can undress at his home. When you are free to remarry, tell me." She continued, "When I was free to remarry, I mentioned to him that Muawiya ibn Abi Sufyan and Abu Jahm ibn Hisham had asked for me in marriage. The Messenger of Allah, may Allah bless him and grant him peace, said, 'As for Abu Jahm, he never puts down his stick from his shoulder (i.e. he is always travelling), and as for Muawiya he is a poor man with no property. Marry Usama ibn Zayd.' I objected to him and he said, 'Marry Usama ibn Zayd,' so I married him, and Allah put good in it and I was content with him}}
\hadithdefcmd{malik}{1226}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ الْمَبْتُوتَةُ لاَ تَخْرُجُ مِنْ بَيْتِهَا حَتَّى تَحِلَّ وَلَيْسَتْ لَهَا نَفَقَةٌ إِلاَّ أَنْ تَكُونَ حَامِلاً فَيُنْفَقُ عَلَيْهَا حَتَّى تَضَعَ حَمْلَهَا ‏.‏ قَالَ مَالِكٌ وَهَذَا الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1226}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard Ibn Shihab say, "The woman who is absolutely divorced does not leave her house until she is free to remarry. She has no maintenance unless she is pregnant. In that circumstance the husband spends on her until she gives birth." Malik said, "This is what is done among us}}
\hadithdefcmd{malik}{1227}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ اللَّيْثِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ أَيُّمَا امْرَأَةٍ طُلِّقَتْ فَحَاضَتْ حَيْضَةً أَوْ حَيْضَتَيْنِ ثُمَّ رَفَعَتْهَا حَيْضَتُهَا فَإِنَّهَا تَنْتَظِرُ تِسْعَةَ أَشْهُرٍ فَإِنْ بَانَ بِهَا حَمْلٌ فَذَلِكَ وَإِلاَّ اعْتَدَّتْ بَعْدَ التِّسْعَةِ الأَشْهُرِ ثَلاَثَةَ أَشْهُرٍ ثُمَّ حَلَّتْ ‏.‏\hadithno{1227}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik said, "What is done among us when a slave divorces a slave- girl when she is a slave and then she is set free, is that her idda is the idda of a slave-girl, and her being set free does not change her idda whether or not he can still return to her. Her idda is not altered." Malik added, "The hadd-punishment which a slave incurs is the same as this. When he is freed after he has incurred but before the punishment has been executed, his hadd is the hadd of the slave." Malik said, "When a free man divorces a slave-girl three times, her idda is two periods. When a slave divorces a free woman twice, her idda is three periods." Malik said about a man who had a slave-girl as a wife, and he bought her and set her free, ''Her idda is the idda of a slave-girl, i.e. two periods, as long as he has not had intercourse with her. If he has had intercourse with her after buying her and before he set her free, she only has to wait until one period has passed . " Yahya related to me from Malik from Yahya ibn Said and from Yazid ibn Abdullah ibn Qusayt al-Laythi that Said ibn al-Musayyab said, ''Umar ibn al-Khattab said, 'If a woman is divorced and has one or two periods and then stops menstruating, she must wait nine months. If it is clear that she is pregnant, that is that. If not, she must do an idda of three months after the nine, and then she is free to marry}}
\hadithdefcmd{malik}{1228}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ الطَّلاَقُ لِلرِّجَالِ وَالْعِدَّةُ لِلنِّسَاءِ ‏.‏\hadithno{1228}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "Divorce belongs to men, and women have the idda}}
\hadithdefcmd{malik}{1229}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ عِدَّةُ الْمُسْتَحَاضَةِ سَنَةٌ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي الْمُطَلَّقَةِ الَّتِي تَرْفَعُهَا حَيْضَتُهَا حِينَ يُطَلِّقُهَا زَوْجُهَا أَنَّهَا تَنْتَظِرُ تِسْعَةَ أَشْهُرٍ فَإِنْ لَمْ تَحِضْ فِيهِنَّ اعْتَدَّتْ ثَلاَثَةَ أَشْهُرٍ فَإِنْ حَاضَتْ قَبْلَ أَنْ تَسْتَكْمِلَ الأَشْهُرَ الثَّلاَثَةَ اسْتَقْبَلَتِ الْحَيْضَ فَإِنْ مَرَّتْ بِهَا تِسْعَةُ أَشْهُرٍ قَبْلَ أَنْ تَحِيضَ اعْتَدَّتْ ثَلاَثَةَ أَشْهُرٍ فَإِنْ حَاضَتِ الثَّانِيَةَ قَبْلَ أَنْ تَسْتَكْمِلَ الأَشْهُرَ الثَّلاَثَةَ اسْتَقْبَلَتِ الْحَيْضَ فَإِنْ مَرَّتْ بِهَا تِسْعَةُ أَشْهُرٍ قَبْلَ أَنْ تَحِيضَ اعْتَدَّتْ ثَلاَثَةَ أَشْهُرٍ فَإِنْ حَاضَتِ الثَّالِثَةَ كَانَتْ قَدِ اسْتَكْمَلَتْ عِدَّةَ الْحَيْضِ فَإِنْ لَمْ تَحِضِ اسْتَقْبَلَتْ ثَلاَثَةَ أَشْهُرٍ ثُمَّ حَلَّتْ وَلِزَوْجِهَا عَلَيْهَا فِي ذَلِكَ الرَّجْعَةُ قَبْلَ أَنْ تَحِلَّ إِلاَّ أَنْ يَكُونَ قَدْ بَتَّ طَلاَقَهَا ‏.‏ قَالَ مَالِكٌ السُّنَّةُ عِنْدَنَا أَنَّ الرَّجُلَ إِذَا طَلَّقَ امْرَأَتَهُ وَلَهُ عَلَيْهَا رَجْعَةٌ فَاعْتَدَّتْ بَعْضَ عِدَّتِهَا ثُمَّ ارْتَجَعَهَا ثُمَّ فَارَقَهَا قَبْلَ أَنْ يَمَسَّهَا أَنَّهَا لاَ تَبْنِي عَلَى مَا مَضَى مِنْ عِدَّتِهَا وَأَنَّهَا تَسْتَأْنِفُ مِنْ يَوْمَ طَلَّقَهَا عِدَّةً مُسْتَقْبَلَةً وَقَدْ ظَلَمَ زَوْجُهَا نَفْسَهُ وَأَخْطَأَ إِنْ كَانَ ارْتَجَعَهَا وَلاَ حَاجَةَ لَهُ بِهَا ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا أَنَّ الْمَرْأَةَ إِذَا أَسْلَمَتْ وَزَوْجُهَا كَافِرٌ ثُمَّ أَسْلَمَ فَهُوَ أَحَقُّ بِهَا مَا دَامَتْ فِي عِدَّتِهَا فَإِنِ انْقَضَتْ عِدَّتُهَا فَلاَ سَبِيلَ لَهُ عَلَيْهَا وَإِنْ تَزَوَّجَهَا بَعْدَ انْقِضَاءِ عِدَّتِهَا لَمْ يُعَدَّ ذَلِكَ طَلاَقًا وَإِنَّمَا فَسَخَهَا مِنْهُ الإِسْلاَمُ بِغَيْرِ طَلاَقٍ ‏.‏\hadithno{1229}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab said, "The idda of the woman who bleeds constantly is a year." Malik said, "What is done among us about a divorced woman whose periods stop when her husband divorces her is that she waits nine months. If she has not had a period in them, she has an idda of three months. If she has a period before the end of the three months, she accepts the period. If another nine months pass without her having a period, she does an idda of three months. If she has a second period before the end of those three months, she accepts the period. If nine months then pass without a period, she does an idda of three months. If she has a third period, the idda of the period is complete. If she does not have a period, she waits three months, and then she is free to marry. Her husband can return to her before she becomes free to marry unless he made her divorce irrevocable." Malik said, "The sunna with us is that when a man divorces his wife and has the option to return to her, and she does part of her idda and then he returns to her and then parts from her before he has had intercourse with her, she does not add to what has passed of her idda. Her husband has wronged himself and erred if he returned to her and had no need of her." Malik said, "What is done among us is that if a woman becomes a muslim while her husband is a kafir and then he becomes muslim, he is entitled to her as long as she is in her idda. If her idda is finished, he has no access to her. If he remarries her after the end of her idda, however, that is not counted as divorce. Islam removed her from him without divorce}}
\hadithdefcmd{malik}{1230}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، قَالَ فِي الْحَكَمَيْنِ اللَّذَيْنِ قَالَ اللَّهُ تَعَالَى ‏\{‏وَإِنْ خِفْتُمْ شِقَاقَ بَيْنِهِمَا فَابْعَثُوا حَكَمًا مِنْ أَهْلِهِ وَحَكَمًا مِنْ أَهْلِهَا إِنْ يُرِيدَا إِصْلاَحًا يُوَفِّقِ اللَّهُ بَيْنَهُمَا إِنَّ اللَّهَ كَانَ عَلِيمًا خَبِيرًا‏\}‏ إِنَّ إِلَيْهِمَا الْفُرْقَةَ بَيْنَهُمَا وَالاِجْتِمَاعَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُ مِنْ أَهْلِ الْعِلْمِ أَنَّ الْحَكَمَيْنِ يَجُوزُ قَوْلُهُمَا بَيْنَ الرَّجُلِ وَامْرَأَتِهِ فِي الْفُرْقَةِ وَالاِجْتِمَاعِ ‏.‏\hadithno{1230}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Ali ibn Abi Talib said about the two arbiters about whom Allah, the Exalted, said,"If you fear a breach between the two, appoint an arbiter from his people, and an arbiter from her people. If they desire to set things aright, Allah will make peace between them, surely Allah is Knowing, Aware," (Sura 4 ayat 35), that the separation and the joining were overseen by the two of them. Malik said, "That is the best of what I have heard from the people of knowledge. Whatever the two arbiters say concerning separation or joining is taken into consideration}}
\hadithdefcmd{malik}{1231}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَعَبْدَ اللَّهِ بْنَ عُمَرَ، وَعَبْدَ اللَّهِ بْنَ مَسْعُودٍ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، وَالْقَاسِمَ بْنَ مُحَمَّدٍ، وَابْنَ، شِهَابٍ وَسُلَيْمَانَ بْنَ يَسَارٍ كَانُوا يَقُولُونَ إِذَا حَلَفَ الرَّجُلُ بِطَلاَقِ الْمَرْأَةِ قَبْلَ أَنْ يَنْكِحَهَا ثُمَّ أَثِمَ إِنَّ ذَلِكَ لاَزِمٌ لَهُ إِذَا نَكَحَهَا ‏.‏\hadithno{1231}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab, Abdullah ibn Umar, Abdullah ibn Masud, Salim ibn Abdullah, al-Qasim ibn Muhammad, Ibn Shihab,and Sulayman ibn Yasar all said, "If a man has vowed to divorce his wife before marrying her and then he breaks his vow, divorce is obligatory for him when he marries her}}
\hadithdefcmd{malik}{1232}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، كَانَ يَقُولُ فِيمَنْ قَالَ كُلُّ امْرَأَةٍ أَنْكِحُهَا فَهِيَ طَالِقٌ إِنَّهُ إِذَا لَمْ يُسَمِّ قَبِيلَةً أَوِ امْرَأَةً بِعَيْنِهَا فَلاَ شَىْءَ عَلَيْهِ ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحْسَنُ مَا سَمِعْتُ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَقُولُ لاِمْرَأَتِهِ أَنْتِ الطَّلاَقُ وَكُلُّ امْرَأَةٍ أَنْكِحُهَا فَهِيَ طَالِقٌ وَمَالُهُ صَدَقَةٌ إِنْ لَمْ يَفْعَلْ كَذَا وَكَذَا فَحَنِثَ قَالَ أَمَّا نِسَاؤُهُ فَطَلاَقٌ كَمَا قَالَ وَأَمَّا قَوْلُهُ كُلُّ امْرَأَةٍ أَنْكِحُهَا فَهِيَ طَالِقٌ فَإِنَّهُ إِذَا لَمْ يُسَمِّ امْرَأَةً بِعَيْنِهَا أَوْ قَبِيلَةً أَوْ أَرْضًا أَوْ نَحْوَ هَذَا فَلَيْسَ يَلْزَمُهُ ذَلِكَ وَلْيَتَزَوَّجْ مَا شَاءَ وَأَمَّا مَالُهُ فَلْيَتَصَدَّقْ بِثُلُثِهِ ‏.‏\hadithno{1232}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Masud said that there was nothing binding on someone who said, "Every woman I marry is divorced," if he did not name a specific tribe or woman. Malik said, "That is the best of what I have heard." Malik said about a man saying to his wife, "You are divorced, and every woman I marry is divorced," or that all his property would be sadaqa if he did not do such-and-such, and he broke his oath:"As for his wives, it is divorce as he said, and as for his statement, 'Every woman I marry is divorced', if he did not name a specific woman, tribe, or land, or such, it is not binding on him and he can marry as he wishes. As for his property, he gives a third of it away as sadaqa}}
\hadithdefcmd{malik}{1233}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ مَنْ تَزَوَّجَ امْرَأَةً فَلَمْ يَسْتَطِعْ أَنْ يَمَسَّهَا فَإِنَّهُ يُضْرَبُ لَهُ أَجَلٌ سَنَةً فَإِنْ مَسَّهَا وَإِلاَّ فُرِّقَ بَيْنَهُمَا ‏.‏\hadithno{1233}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab said, "If someone marries a woman and cannot have intercourse with her, there is a deadline of a year set for him to have intercourse with her. If he does not, they are separated}}
\hadithdefcmd{malik}{1234}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ مَتَى يُضْرَبُ لَهُ الأَجَلُ أَمِنْ يَوْمِ يَبْنِي بِهَا أَمْ مِنْ يَوْمِ تُرَافِعُهُ إِلَى السُّلْطَانِ فَقَالَ بَلْ مِنْ يَوْمِ تُرَافِعُهُ إِلَى السُّلْطَانِ ‏.‏ قَالَ مَالِكٌ فَأَمَّا الَّذِي قَدْ مَسَّ امْرَأَتَهُ ثُمَّ اعْتَرَضَ عَنْهَا فَإِنِّي لَمْ أَسْمَعْ أَنَّهُ يُضْرَبُ لَهُ أَجَلٌ وَلاَ يُفَرَّقُ بَيْنَهُمَا ‏.‏\hadithno{1234}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had asked Ibn Shihab about whether the deadline was set from the day he had married her, or from the day she raised the question before the Sultan. He said. 'It is from the day she presents it before the Sultan.' Malik said, "As for someone who has intercourse with his wife and then is prevented from intercourse with her, I have not heard that there is a deadline set for him or that they are separated}}
\hadithdefcmd{malik}{1235}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ مِنْ ثَقِيفٍ أَسْلَمَ وَعِنْدَهُ عَشْرُ نِسْوَةٍ حِينَ أَسْلَمَ الثَّقَفِيُّ ‏ "‏ أَمْسِكْ مِنْهُنَّ أَرْبَعًا وَفَارِقْ سَائِرَهُنَّ ‏"‏ ‏.‏\hadithno{1235}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "I have heard that the Messenger of Allah, may Allah bless him and grant him peace, said to a man from Thaqif who had ten wives when he became muslim, 'Take four and separate from the rest}}
\hadithdefcmd{malik}{1236}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، وَحُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، وَسُلَيْمَانَ بْنَ يَسَارٍ، كُلُّهُمْ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ أَيُّمَا امْرَأَةٍ طَلَّقَهَا زَوْجُهَا تَطْلِيقَةً أَوْ تَطْلِيقَتَيْنِ ثُمَّ تَرَكَهَا حَتَّى تَحِلَّ وَتَنْكِحَ زَوْجًا غَيْرَهُ فَيَمُوتَ عَنْهَا أَوْ يُطَلِّقَهَا ثُمَّ يَنْكِحُهَا زَوْجُهَا الأَوَّلُ فَإِنَّهَا تَكُونُ عِنْدَهُ عَلَى مَا بَقِيَ مِنْ طَلاَقِهَا ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ السُّنَّةُ عِنْدَنَا الَّتِي لاَ اخْتِلاَفَ فِيهَا ‏.‏\hadithno{1236}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said that he had heard Said ibn al-Musayyab, Humayd ibn Abd ar-Rahman ibn Awf, Ubaydullah ibn Abdullah ibn Utba ibn Masud, and Sulayman ibn Yasarall say, that they had heard Abu Hurayra say that he had heard Umar ibn al-Khattab say, "If a woman is divorced by her husband once or twice, and he leaves her until she is free to marry and she marries another husband and he dies or divorces her, and then she marries her first husband, she is with him according to what remains of her divorce." Malik said, "That is what is done among us and there is no dispute about it}}
\hadithdefcmd{malik}{1237}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَابِتِ بْنِ الأَحْنَفِ، أَنَّهُ تَزَوَّجَ أُمَّ وَلَدٍ لِعَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ - قَالَ - فَدَعَانِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ فَجِئْتُهُ فَدَخَلْتُ عَلَيْهِ فَإِذَا سِيَاطٌ مَوْضُوعَةٌ وَإِذَا قَيْدَانِ مِنْ حَدِيدٍ وَعَبْدَانِ لَهُ قَدْ أَجْلَسَهُمَا فَقَالَ طَلِّقْهَا وَإِلاَّ وَالَّذِي يُحْلَفُ بِهِ فَعَلْتُ بِكَ كَذَا وَكَذَا ‏.‏ قَالَ فَقُلْتُ هِيَ الطَّلاَقُ أَلْفًا ‏.‏ قَالَ فَخَرَجْتُ مِنْ عِنْدِهِ فَأَدْرَكْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ بِطَرِيقِ مَكَّةَ فَأَخْبَرْتُهُ بِالَّذِي كَانَ مِنْ شَأْنِي فَتَغَيَّظَ عَبْدُ اللَّهِ وَقَالَ لَيْسَ ذَلِكَ بِطَلاَقٍ وَإِنَّهَا لَمْ تَحْرُمْ عَلَيْكَ فَارْجِعْ إِلَى أَهْلِكَ ‏.‏ قَالَ فَلَمْ تُقْرِرْنِي نَفْسِي حَتَّى أَتَيْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ - وَهُوَ يَوْمَئِذٍ بِمَكَّةَ أَمِيرٌ عَلَيْهَا - فَأَخْبَرْتُهُ بِالَّذِي كَانَ مِنْ شَأْنِي وَبِالَّذِي قَالَ لِي عَبْدُ اللَّهِ بْنُ عُمَرَ قَالَ فَقَالَ لِي عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ لَمْ تَحْرُمْ عَلَيْكَ فَارْجِعْ إِلَى أَهْلِكَ ‏.‏ وَكَتَبَ إِلَى جَابِرِ بْنِ الأَسْوَدِ الزُّهْرِيِّ - وَهُوَ أَمِيرُ الْمَدِينَةِ - يَأْمُرُهُ أَنْ يُعَاقِبَ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ وَأَنْ يُخَلِّيَ بَيْنِي وَبَيْنَ أَهْلِي - قَالَ - فَقَدِمْتُ الْمَدِينَةَ فَجَهَّزَتْ صَفِيَّةُ امْرَأَةُ عَبْدِ اللَّهِ بْنِ عُمَرَ امْرَأَتِي حَتَّى أَدْخَلَتْهَا عَلَىَّ بِعِلْمِ عَبْدِ اللَّهِ بْنِ عُمَرَ ثُمَّ دَعَوْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَوْمَ عُرْسِي لِوَلِيمَتِي فَجَاءَنِي ‏.‏\hadithno{1237}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Thabit ibn al-Ahnaf that he married an umm walad of Abd ar-Rahman ibn Zayd ibn al-Khattab. He said, "Abdullah ibn Abd ar-Rahman ibn Zayd ibn al-Khattab summoned me and I went to him. I came in upon him and there were whips and two iron fetters placed there, and two of his slaves whom he had made to sit there. He said, 'Divorce her, or by He by whom one swears, I will do such-and-such to you!' I said, 'It is divorce a thousand times.' Then I left him and I saw Abdullah ibn Umar on the road to Makka and I told him about my situation. Abdullah ibn Umar was furious, and said, 'That is not divorce, and she is not haram for you, so return to your home.' I was still not at ease so I went to Abdullah ibn az-Zubayr who was the Amir of Makka at that time. I told him about my situation and what Abdullah ibn Umar had said to me. Abdullah ibn az-Zubayr said to me, 'She is not haram for you, so return to your home,' and he wrote to Jabir ibn al-Aswad az-Zuhra who was the Amir of Madina and ordered him to punish Abdullah ibn Abdar-Rahman and to have him leave me and my family alone. I went to Madina, and Safiyya, the wife of Abdullah ibn Umar fitted out my wife so that she could bring her to my house with the knowledge of Abdullah ibn Umar. Then I invited Abdullah ibn Umar on the day of my wedding to the wedding feast and he came}}
\hadithdefcmd{malik}{1238}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَرَأَ ‏\{‏يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ‏\}‏ لِقُبُلِ عِدَّتِهِنَّ ‏.‏ قَالَ مَالِكٌ يَعْنِي بِذَلِكَ أَنْ يُطَلِّقَ فِي كُلِّ طُهْرٍ مَرَّةً ‏.‏\hadithno{1238}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Dinar said, "I heard Abdullah ibn Umar recite from the Qur'an, 'Prophet! When you divorce women, divorce them at the beginning of their idda.'" Malik said, "He meant by that, to make one pronouncement of divorce at the beginning of each period of purity}}
\hadithdefcmd{malik}{1239}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كَانَ الرَّجُلُ إِذَا طَلَّقَ امْرَأَتَهُ ثُمَّ ارْتَجَعَهَا قَبْلَ أَنْ تَنْقَضِيَ عِدَّتُهَا كَانَ ذَلِكَ لَهُ وَإِنْ طَلَّقَهَا أَلْفَ مَرَّةٍ فَعَمَدَ رَجُلٌ إِلَى امْرَأَتِهِ فَطَلَّقَهَا حَتَّى إِذَا شَارَفَتِ انْقِضَاءَ عِدَّتِهَا رَاجَعَهَا ثُمَّ طَلَّقَهَا ثُمَّ قَالَ لاَ وَاللَّهِ لاَ آوِيكِ إِلَىَّ وَلاَ تَحِلِّينَ أَبَدًا ‏.‏ فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏الطَّلاَقُ مَرَّتَانِ فَإِمْسَاكٌ بِمَعْرُوفٍ أَوْ تَسْرِيحٌ بِإِحْسَانٍ‏\}‏ فَاسْتَقْبَلَ النَّاسُ الطَّلاَقَ جَدِيدًا مِنْ يَوْمِئِذٍ مَنْ كَانَ طَلَّقَ مِنْهُمْ أَوْ لَمْ يُطَلِّقْ ‏.‏\hadithno{1239}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "It used to be that a man would divorce his wife and then return to her before her idda was over, and that was alright, even if he divorced her a thousand times. The man went to his wife and then divorced her and when the end of her idda was in sight, he took her back and then divorced her and said, 'No! By Allah, I will not go to you and you will never be able to marry again.' Allah, the Blessed, the Exalted, sent down, 'Divorce is twice, then honourable retention or setting free kindly.' People then turned towards divorce in a new light from that day whether or not they were divorced or not divorced}}
\hadithdefcmd{malik}{1240}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، أَنَّ الرَّجُلَ، كَانَ يُطَلِّقُ امْرَأَتَهُ ثُمَّ يُرَاجِعُهَا وَلاَ حَاجَةَ لَهُ بِهَا وَلاَ يُرِيدُ إِمْسَاكَهَا كَيْمَا يُطَوِّلَ بِذَلِكَ عَلَيْهَا الْعِدَّةَ لِيُضَارَّهَا فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏وَلاَ تُمْسِكُوهُنَّ ضِرَارًا لِتَعْتَدُوا وَمَنْ يَفْعَلْ ذَلِكَ فَقَدْ ظَلَمَ نَفْسَهُ‏\}‏ يَعِظُهُمُ اللَّهُ بِذَلِكَ ‏.‏\hadithno{1240}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili that Allah, the Blessed, the Exalted, sent down about a man who divorced his wife and then returned to her while he had no need of her and did not mean to keep her so as to make the idda period long for her by that in order to do her harm, "Do not retain them by force, to transgress. Whoever does that has wronged himself." (Sura 2 ayat 231). Allah warns them by that ayat}}
\hadithdefcmd{malik}{1241}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، سُئِلاَ عَنْ طَلاَقِ السَّكْرَانِ، فَقَالاَ إِذَا طَلَّقَ السَّكْرَانُ جَازَ طَلاَقُهُ وَإِنْ قَتَلَ قُتِلَ بِهِ ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1241}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Sulayman ibn Yasar were asked about a man who divorced when he was drunk. They said, "When a drunk man divorces, his divorce is allowed. If he kills, he is killed for it." Malik said, "That is what is done among us}}
\hadithdefcmd{malik}{1242}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، كَانَ يَقُولُ إِذَا لَمْ يَجِدِ الرَّجُلُ مَا يُنْفِقُ عَلَى امْرَأَتِهِ فُرِّقَ بَيْنَهُمَا ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ أَدْرَكْتُ أَهْلَ الْعِلْمِ بِبَلَدِنَا ‏.‏\hadithno{1242}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab said, "If a man does not find the means to spend on his wife, they are to be separated . " Malik said, "That is what I saw the people of knowledge in our city doing." 29.30 Idda of Widows when Pregnant}}
\hadithdefcmd{malik}{1243}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدِ بْنِ قَيْسٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ سُئِلَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ وَأَبُو هُرَيْرَةَ عَنِ الْمَرْأَةِ الْحَامِلِ يُتَوَفَّى عَنْهَا زَوْجُهَا فَقَالَ ابْنُ عَبَّاسٍ آخِرَ الأَجَلَيْنِ ‏.‏ وَقَالَ أَبُو هُرَيْرَةَ إِذَا وَلَدَتْ فَقَدْ حَلَّتْ ‏.‏ فَدَخَلَ أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَلَى أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهَا عَنْ ذَلِكَ فَقَالَتْ أُمُّ سَلَمَةَ وَلَدَتْ سُبَيْعَةُ الأَسْلَمِيَّةُ بَعْدَ وَفَاةِ زَوْجِهَا بِنِصْفِ شَهْرٍ فَخَطَبَهَا رَجُلاَنِ أَحَدُهُمَا شَابٌّ وَالآخَرُ كَهْلٌ فَحَطَّتْ إِلَى الشَّابِّ فَقَالَ الشَّيْخُ لَمْ تَحِلِّي بَعْدُ ‏.‏ وَكَانَ أَهْلُهَا غَيَبًا وَرَجَا إِذَا جَاءَ أَهْلُهَا أَنْ يُؤْثِرُوهُ بِهَا فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَدْ حَلَلْتِ فَانْكِحِي مَنْ شِئْتِ ‏"‏ ‏.‏\hadithno{1243}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdu Rabbih ibn Said ibn Qays that Abu Salama ibn Abd ar-Rahman said that Abdullah ibn Abbas and Abu Hurayra were asked when a pregnant woman whose husband had died could remarry. Ibn Abbas said, "At the end of two periods." Abu Hurayra said, "When she gives birth, she is free to marry." Abu Salama ibn Abd ar-Rahman visited Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, and asked her about it Umm Salama said, ''Subaya al-Aslamiya gave birth half a month after the death of her husband, and two men asked to marry her. One was young and the other was old. She preferred the young man and so the older man said, 'You are not free to marry yet.' Her family were away and he hoped that when her family came, they would give her to him. She went to the Messenger of Allah, may Allah bless him and grant him peace, and he said, 'You are free to marry, so marry whomever you wish}}
\hadithdefcmd{malik}{1244}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ سُئِلَ عَنِ الْمَرْأَةِ، يُتَوَفَّى عَنْهَا زَوْجُهَا وَهِيَ حَامِلٌ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ إِذَا وَضَعَتْ حَمْلَهَا فَقَدْ حَلَّتْ ‏.‏ فَأَخْبَرَهُ رَجُلٌ مِنَ الأَنْصَارِ كَانَ عِنْدَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ قَالَ لَوْ وَضَعَتْ وَزَوْجُهَا عَلَى سَرِيرِهِ لَمْ يُدْفَنْ بَعْدُ لَحَلَّتْ ‏.‏\hadithno{1244}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar was asked about a woman whose husband died while she was pregnant, and he said, "When she gives birth, she is free to marry." A man of the Ansar who was with him told him that Umar ibn al-Khattab had said, "Had she given birth while her husband was still on his bed, unburied, she would be free to marry}}
\hadithdefcmd{malik}{1245}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّهُ أَخْبَرَهُ أَنَّ سُبَيْعَةَ الأَسْلَمِيَّةَ نُفِسَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ حَلَلْتِ فَانْكِحِي مَنْ شِئْتِ ‏"‏ ‏.‏\hadithno{1245}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn 'Urwa from his father that al-Miswar ibn Makhrama told him that Subaya al-Aslamiya gave birth a few nights after the death of her husband. The Messenger of Allah, may Allah bless him and grant him peace, said to her, "You are free to marry, so marry whomever you wish}}
\hadithdefcmd{malik}{1246}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَأَبَا، سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ اخْتَلَفَا فِي الْمَرْأَةِ تُنْفَسُ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ فَقَالَ أَبُو سَلَمَةَ إِذَا وَضَعَتْ مَا فِي بَطْنِهَا فَقَدْ حَلَّتْ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ آخِرَ الأَجَلَيْنِ ‏.‏ فَجَاءَ أَبُو هُرَيْرَةَ فَقَالَ أَنَا مَعَ ابْنِ أَخِي ‏.‏ يَعْنِي أَبَا سَلَمَةَ فَبَعَثُوا كُرَيْبًا مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ إِلَى أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم يَسْأَلُهَا عَنْ ذَلِكَ فَجَاءَهُمْ فَأَخْبَرَهُمْ أَنَّهَا قَالَتْ وَلَدَتْ سُبَيْعَةُ الأَسْلَمِيَّةُ بَعْدَ وَفَاةِ زَوْجِهَا بِلَيَالٍ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَدْ حَلَلْتِ فَانْكِحِي مَنْ شِئْتِ ‏"‏ ‏.‏\hadithno{1246}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Sulayman ibn Yasar that Abdullah ibn Abbas and Abu Salama ibn Abd ar-Rahman ibn Awf differed on the question of a wornan who gave birth a few nights after the death of her husband. Abu Salama said, "When she gives birth to the child she is carrying, she is free to marry." Ibn Abbas said, "At the end of two periods." Abu Hurayra came and said, "I am with my nephew", meaning Abu Salama. They sent Kurayb, a mawla of Abdullah ibn Abbas to Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, to ask her about it. He came back and told them that she had said that Subaya al-Aslamiya had given birth a few nights after the death of her husband, and she had brought the matter to the Messenger of Allah, may Allah bless him and grant him peace, and he had said, "You are free to marry, so marry whomever you wish." Malik said, "This is how the people of knowledge here continue to act." 29.31 Widows Remaining in Their Houses until Free to Marry}}
\hadithdefcmd{malik}{1247}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، عَنْ عَمَّتِهِ، زَيْنَبَ بِنْتِ كَعْبِ بْنِ عُجْرَةَ أَنَّ الْفُرَيْعَةَ بِنْتَ مَالِكِ بْنِ سِنَانٍ، - وَهِيَ أُخْتُ أَبِي سَعِيدٍ الْخُدْرِيِّ - أَخْبَرَتْهَا أَنَّهَا، جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَسْأَلُهُ أَنْ تَرْجِعَ إِلَى أَهْلِهَا فِي بَنِي خُدْرَةَ فَإِنَّ زَوْجَهَا خَرَجَ فِي طَلَبِ أَعْبُدٍ لَهُ أَبَقُوا حَتَّى إِذَا كَانُوا بِطَرَفِ الْقَدُومِ لَحِقَهُمْ فَقَتَلُوهُ ‏.‏ قَالَتْ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ أَرْجِعَ إِلَى أَهْلِي فِي بَنِي خُدْرَةَ فَإِنَّ زَوْجِي لَمْ يَتْرُكْنِي فِي مَسْكَنٍ يَمْلِكُهُ وَلاَ نَفَقَةَ ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ فَانْصَرَفْتُ حَتَّى إِذَا كُنْتُ فِي الْحُجْرَةِ نَادَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ أَمَرَ بِي فَنُودِيتُ لَهُ فَقَالَ ‏"‏ كَيْفَ قُلْتِ ‏"‏ ‏.‏ فَرَدَّدْتُ عَلَيْهِ الْقِصَّةَ الَّتِي ذَكَرْتُ لَهُ مِنْ شَأْنِ زَوْجِي فَقَالَ ‏"‏ امْكُثِي فِي بَيْتِكِ حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏ قَالَتْ فَاعْتَدَدْتُ فِيهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا - قَالَتْ - فَلَمَّا كَانَ عُثْمَانُ بْنُ عَفَّانَ أَرْسَلَ إِلَىَّ فَسَأَلَنِي عَنْ ذَلِكَ فَأَخْبَرْتُهُ فَاتَّبَعَهُ وَقَضَى بِهِ ‏.‏\hadithno{1247}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Ishaq ibn Kab ibn Ujra from his paternal aunt, Zaynab bint Kab ibn Ujra that al-Furaya bint Malik ibn Sinan, the sister of Abu Said al-Khudri, informed her that she went to the Messenger of Allah, may Allah bless him and grant him peace, and asked to be able to return to her people among the Banu Khudra since her husband had gone out in search of some of his slaves who had run away and he had caught up with them near al-Qudum, (which is 6 miles from Madina), and they had killed him. She said, "I asked the Messenger of Allah, may Allah bless him and grant him peace, if I could return to my people in the Banu Khudra, as my husband had not left me in a dwelling which belonged to him, and had left me no maintenance. The Messenger of Allah, may Allah bless him and grant him peace, said,'Yes.' So I left. When I was in the courtyard, the Messenger of Allah, may Allah bless him and grant him peace, called me or summoned me, and I answered him. He said, 'What did you say?' I repeated the story about my husband. He said, 'Stay in your house until what is written reaches its term.' I did the idda in the house for four months and ten days." She added, "When Uthman ibn Affan sent for me, I told him that, and he followed it and made decisions by it}}
\hadithdefcmd{malik}{1248}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ الْمَكِّيِّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، ‏.‏ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَرُدُّ الْمُتَوَفَّى عَنْهُنَّ أَزْوَاجُهُنَّ مِنَ الْبَيْدَاءِ يَمْنَعُهُنَّ الْحَجَّ ‏.‏\hadithno{1248}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Humayd ibn Qays al-Makki from Amr ibn Shuayb from Said ibn al-Musayyab that Umar ibn al-Khattab sent back widows from the desert and prevented them from doing the hajj}}
\hadithdefcmd{malik}{1249}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ أَنَّ السَّائِبَ بْنَ خَبَّابٍ، تُوُفِّيَ وَإِنَّ امْرَأَتَهُ جَاءَتْ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ فَذَكَرَتْ لَهُ وَفَاةَ زَوْجِهَا وَذَكَرَتْ لَهُ حَرْثًا لَهُمْ بِقَنَاةَ وَسَأَلَتْهُ هَلْ يَصْلُحُ لَهَا أَنْ تَبِيتَ فِيهِ فَنَهَاهَا عَنْ ذَلِكَ فَكَانَتْ تَخْرُجُ مِنَ الْمَدِينَةِ سَحَرًا فَتُصْبِحُ فِي حَرْثِهِمْ فَتَظَلُّ فِيهِ يَوْمَهَا ثُمَّ تَدْخُلُ الْمَدِينَةَ إِذَا أَمْسَتْ فَتَبِيتُ فِي بَيْتِهَا ‏.‏\hadithno{1249}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Saqd that he had heard that as-Sa'ib ibn Khabbab died, and his wife went to Abdullah ibn Umar and mentioned to him that her husband had died and mentioned some land which they had at Qanah, (a district on the outskirts of Madina), and asked him if it would be alright for her to stay overnight there. He forbade her to do so. So, she went out before dawn from Madina and spent the whole day on their land, but when evening came, she spent the night in her house}}
\hadithdefcmd{malik}{1250}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ فِي الْمَرْأَةِ الْبَدَوِيَّةِ يُتَوَفَّى عَنْهَا زَوْجُهَا إِنَّهَا تَنْتَوِي حَيْثُ انْتَوَى أَهْلُهَا ‏.‏ قَالَ مَالِكٌ وَهَذَا الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1250}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Hisham ibn Urwa said about a Bedouin woman whose husband died, that she was to stay where her people stayed. Malik said, "This is what is done among us}}
\hadithdefcmd{malik}{1251}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ لاَ تَبِيتُ الْمُتَوَفَّى عَنْهَا زَوْجُهَا وَلاَ الْمَبْتُوتَةُ إِلاَّ فِي بَيْتِهَا ‏.‏\hadithno{1251}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullan ibn Umar said, "The only place a woman whose husband has died and a woman who is absolutely divorced can spend the night is in their houses}}
\hadithdefcmd{malik}{1252}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، يَقُولُ إِنَّ يَزِيدَ بْنَ عَبْدِ الْمَلِكِ فَرَّقَ بَيْنَ رِجَالٍ وَبَيْنَ نِسَائِهِمْ وَكُنَّ أُمَّهَاتِ أَوْلاَدِ رِجَالٍ هَلَكُوا فَتَزَوَّجُوهُنَّ بَعْدَ حَيْضَةٍ أَوْ حَيْضَتَيْنِ فَفَرَّقَ بَيْنَهُمْ حَتَّى يَعْتَدُّونَ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏ فَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ سُبْحَانَ اللَّهِ يَقُولُ اللَّهُ فِي كِتَابِهِ ‏\{‏وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا‏\}‏ مَا هُنَّ مِنَ الأَزْوَاجِ ‏.‏\hadithno{1252}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he had heard al-Qasim ibn Muhammad say that Zayd ibn Abd al-Malik separated some men and their wives who were slave-girls who had borne children to men who had died, because they had married them after one or two menstrual periods. He separated them until they had done an idda of four months and ten days. Al-Qasim ibn Muhammad said, "Glory be to Allah! Allah says in His Book, 'Those of you who die, leaving wives, they are not wives}}
\hadithdefcmd{malik}{1253}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ عِدَّةُ أُمِّ الْوَلَدِ إِذَا تُوُفِّيَ عَنْهَا سَيِّدُهَا حَيْضَةٌ ‏.‏\hadithno{1253}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that Abdullah ibn Umar said, "The idda of an umm walad when her master dies is one menstrual period}}
\hadithdefcmd{malik}{1254}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ كَانَ يَقُولُ عِدَّةُ أُمِّ الْوَلَدِ إِذَا تُوُفِّيَ عَنْهَا سَيِّدُهَا حَيْضَةٌ ‏.‏ قَالَ مَالِكٌ وَهُوَ الأَمْرُ عِنْدَنَا ‏.‏ قَالَ مَالِكٌ وَإِنْ لَمْ تَكُنْ مِمَّنْ تَحِيضُ فَعِدَّتُهَا ثَلاَثَةُ أَشْهُرٍ ‏.‏\hadithno{1254}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik said, "This is what is done among us." Malik added, "If she does not have a menstrual period, her idda is three months}}
\hadithdefcmd{malik}{1255}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، كَانَا يَقُولاَنِ عِدَّةُ الأَمَةِ إِذَا هَلَكَ عَنْهَا زَوْجُهَا شَهْرَانِ وَخَمْسُ لَيَالٍ ‏.‏\hadithno{1255}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Sulayman ibn Yasar said, "The idda of a slave-girl when her husband dies is two months and five days}}
\hadithdefcmd{malik}{1256}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، مِثْلَ ذَلِكَ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ يُطَلِّقُ الأَمَةَ طَلاَقًا لَمْ يَبُتَّهَا فِيهِ لَهُ عَلَيْهَا فِيهِ الرَّجْعَةُ ثُمَّ يَمُوتُ وَهِيَ فِي عِدَّتِهَا مِنْ طَلاَقِهِ إِنَّهَا تَعْتَدُّ عِدَّةَ الأَمَةِ الْمُتَوَفَّى عَنْهَا زَوْجُهَا شَهْرَيْنِ وَخَمْسَ لَيَالٍ وَإِنَّهَا إِنْ عَتَقَتْ وَلَهُ عَلَيْهَا رَجْعَةٌ ثُمَّ لَمْ تَخْتَرْ فِرَاقَهُ بَعْدَ الْعِتْقِ حَتَّى يَمُوتَ وَهِيَ فِي عِدَّتِهَا مِنْ طَلاَقِهِ اعْتَدَّتْ عِدَّةَ الْحُرَّةِ الْمُتَوَفَّى عَنْهَا زَوْجُهَا أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا وَذَلِكَ أَنَّهَا إِنَّمَا وَقَعَتْ عَلَيْهَا عِدَّةُ الْوَفَاةِ بَعْدَ مَا عَتَقَتْ فَعِدَّتُهَا عِدَّةُ الْحُرَّةِ ‏.‏ قَالَ مَالِكٌ وَهَذَا الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1256}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me the like of that from Malik from Ibn Shihab. Malik said, about a slave who divorced a slave-girl but did not make it absolute, "He can return to her. If he then dies while she is still in the idda from her divorce, she does the idda of a slave- girl whose husband dies, and it is two months and five days. If she has been set free and he can return to her, and she does not choose to separate after she has been set free, and he dies while she is in the idda from the divorce, she does the idda of a free woman whose husband has died, four months and ten days. That is because the idda of widowhood befell her while she was free, so her idda is the idda of a free woman." Malik said, "That is what is done among us}}
\hadithdefcmd{malik}{1257}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، أَنَّهُ قَالَ دَخَلْتُ الْمَسْجِدَ فَرَأَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ فَجَلَسْتُ إِلَيْهِ فَسَأَلْتُهُ عَنِ الْعَزْلِ، فَقَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ بَنِي الْمُصْطَلِقِ فَأَصَبْنَا سَبْيًا مِنْ سَبْىِ الْعَرَبِ فَاشْتَهَيْنَا النِّسَاءَ وَاشْتَدَّتْ عَلَيْنَا الْعُزْبَةُ وَأَحْبَبْنَا الْفِدَاءَ فَأَرَدْنَا أَنْ نَعْزِلَ فَقُلْنَا نَعْزِلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا قَبْلَ أَنْ نَسْأَلَهُ ‏.‏ فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ مَا عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا مَا مِنْ نَسَمَةٍ كَائِنَةٍ إِلَى يَوْمِ الْقِيَامَةِ إِلاَّ وَهِيَ كَائِنَةٌ ‏"‏ ‏.‏\hadithno{1257}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman from Muhammad ibn Yahya ibn Habban that Ibn Muhayriz said, "I went into the mosque and saw Abu Said al-Khudri and so I sat by him and asked him about coitus interruptus. Abu Said al-Khudri said, 'We went out with the Messenger of Allah, may Allah bless him and grant him peace, on the expedition to the Banu al-Mustaliq. We took some Arabs prisoner, and we desired the women as celibacy was hard for us. We wanted the ransom, so we wanted to practise coitus interruptus. We said, 'Shall we practise coitus interruptus while the Messenger of Allah, may Allah bless him and grant him peace, is among us before we ask him?' We asked him about that and he said, 'You don't have to not do it. There is no self which is to come into existence up to the Day of Rising but that it will come into existence}}
\hadithdefcmd{malik}{1258}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَعْزِلُ ‏.‏\hadithno{1258}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n-Nadr, the mawla of Umar ibn Ubaydullah from Amir ibn Sad ibn Abi Waqqas from his father that he used to practise coitus interruptus}}
\hadithdefcmd{malik}{1259}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنِ ابْنِ أَفْلَحَ، مَوْلَى أَبِي أَيُّوبَ الأَنْصَارِيِّ عَنْ أُمِّ وَلَدٍ، لأَبِي أَيُّوبَ الأَنْصَارِيِّ أَنَّهُ كَانَ يَعْزِلُ ‏.‏\hadithno{1259}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abu'n-Nadr, the mawla of Umar ibn Ubaydullah from Ibn Aflah, the mawla of Abu Ayyub al-Ansari from an umm walad of Abu Ayyubal-Ansari that he practised coitus interruptus}}
\hadithdefcmd{malik}{1260}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ لاَ يَعْزِلُ وَكَانَ يَكْرَهُ الْعَزْلَ ‏.‏\hadithno{1260}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar did not practise coitus interruptus and thought that it was disapproved}}
\hadithdefcmd{malik}{1261}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ الْمَازِنِيِّ، عَنِ الْحَجَّاجِ بْنِ عَمْرِو بْنِ غَزِيَّةَ، أَنَّهُ كَانَ جَالِسًا عِنْدَ زَيْدِ بْنِ ثَابِتٍ فَجَاءَهُ ابْنُ قَهْدٍ - رَجُلٌ مِنْ أَهْلِ الْيَمَنِ - فَقَالَ يَا أَبَا سَعِيدٍ إِنَّ عِنْدِي جَوَارِيَ لِي لَيْسَ نِسَائِي اللاَّتِي أُكِنُّ بِأَعْجَبَ إِلَىَّ مِنْهُنَّ وَلَيْسَ كُلُّهُنَّ يُعْجِبُنِي أَنْ تَحْمِلَ مِنِّي أَفَأَعْزِلُ فَقَالَ زَيْدُ بْنُ ثَابِتٍ أَفْتِهِ يَا حَجَّاجُ ‏.‏ قَالَ فَقُلْتُ يَغْفِرُ اللَّهُ لَكَ إِنَّمَا نَجْلِسُ عِنْدَكَ لِنَتَعَلَّمَ مِنْكَ ‏.‏ قَالَ أَفْتِهِ ‏.‏ قَالَ فَقُلْتُ هُوَ حَرْثُكَ إِنْ شِئْتَ سَقَيْتَهُ وَإِنْ شِئْتَ أَعْطَشْتَهُ ‏.‏ قَالَ وَكُنْتُ أَسْمَعُ ذَلِكَ مِنْ زَيْدٍ فَقَالَ زَيْدٌ صَدَقَ ‏.‏\hadithno{1261}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Damra ibn Said al-Mazini from al-Hajjaj ibn Amr ibn Ghaziya that he was sitting with Zayd ibn Thabit when Ibn Fahd came to him. He was from the Yemen. He said, "Abu Said! I have slave-girls. None of the wives in my keep are more pleasing to me than them, and not all of them please me so much that I want a child by them, shall I then practise coitus interruptus?" Zayd ibn Thabit said, "Give an opinion, Hajjaj!" "I said, 'May Allah forgive you! We sit with you in order to learn from you!' He said, 'Give an opinion! 'I said, 'She is your field, if you wish, water it, and if you wish, leave it thirsty. I heard that from Zayd.' Zayd said, 'He has spoken the truth}}
\hadithdefcmd{malik}{1262}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ الْمَكِّيِّ، عَنْ رَجُلٍ، يُقَالُ لَهُ ذَفِيفٌ أَنَّهُ قَالَ سُئِلَ ابْنُ عَبَّاسٍ عَنِ الْعَزْلِ فَدَعَا جَارِيَةً لَهُ فَقَالَ أَخْبِرِيهِمْ ‏.‏ فَكَأَنَّهَا اسْتَحْيَتْ ‏.‏ فَقَالَ هُوَ ذَلِكَ أَمَّا أَنَا فَأَفْعَلُهُ ‏.‏ يَعْنِي أَنَّهُ يَعْزِلُ ‏.‏ قَالَ مَالِكٌ لاَ يَعْزِلُ الرَّجُلُ عَنِ الْمَرْأَةِ الْحُرَّةِ إِلاَّ بِإِذْنِهَا وَلاَ بَأْسَ أَنْ يَعْزِلَ عَنْ أَمَتِهِ بِغَيْرِ إِذْنِهَا وَمَنْ كَانَتْ تَحْتَهُ أَمَةُ قَوْمٍ فَلاَ يَعْزِلُ إِلاَّ بِإِذْنِهِمْ ‏.‏\hadithno{1262}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Humayd ibn Qays al-Makki that a man called Dhafif said that Ibn Abbas was asked about coitus interruptus. He called a slave-girl of his and said, "Tell them." She was embarrassed. He said, "It is alright, and I do it myself." Malik said, "A man does not practise coitus interruptus with a free woman unless she gives her permission. There is no harm in practising coitus interruptus with a slave-girl without her permission. Someone who has someone else's slave-girl as a wife, does not practise coitus interruptus with her unless her people give him permission}}
\hadithdefcmd{malik}{1263}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ هَذِهِ الأَحَادِيثَ الثَّلاَثَةَ، قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ بْنُ حَرْبٍ فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ بِهِ جَارِيَةً ثُمَّ مَسَحَتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيْتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{1263}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm from Humayd ibn Nafi that Zaynab bint Abi Salama related these three traditions to him. Zaynab said, "I visited Umm Habiba, the wife of the Prophet, may Allah bless him and grant him peace, when her father Abu Sufyan ibn Harb had died. Umm Habiba called for a yellowy perfume perhaps khaluq or something else. She rubbed the perfume first on a slave-girl and she then wiped it on the sides of her face and said, 'By Allah! I have no need of perfume but I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'It is not halal for a woman who trusts in Allah and the Last Day to abstain from adornment in mourning for someone who has died, for more than three nights, except for four months and ten days for a husband}}
\hadithdefcmd{malik}{1264}{قَالَتْ زَيْنَبُ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ حَاجَةٌ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيْتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{1264}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Zaynab said, "I went to the house of Zaynab bint Jahsh, the wife of the Prophet, may Allah bless him and grant him peace, when her brother had died. She called for perfume and put some on and said, 'By Allah! I have no need of perfume, but I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'It is not halal for a woman who trusts in Allah and the Last Day to abstain from adornment in mourning for someone who has died for more than three nights, except for four months and ten days for a husband}}
\hadithdefcmd{malik}{1265}{قَالَتْ زَيْنَبُ وَسَمِعْتُ أُمِّي أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنَيْهَا أَفَتَكْحُلُهُمَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلُّ ذَلِكَ يَقُولُ ‏"‏ لاَ ‏"‏ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعْرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدُ بْنُ نَافِعٍ فَقُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعْرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَيْرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعْرَةً فَتَرْمِي بِهَا ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏\hadithno{1265}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Zaynab said, "I heard my mother, Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, say that a woman came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah! My daughter's husband died, and her eyes are troubling her, can she put kohl on them?' The Messenger of Allah, may Allah bless him and grant him peace, said, 'No' two or three times. Then he said, 'It is only four months and ten days. In the Jahiliyya, none of you threw away the piece of dung until a year had passed.' " Humayd ibn Nafi said, "I asked Zaynab to explain what 'throwing away the piece of dung at the end of a year' meant. Zaynab said, 'In the Jahiliyya when a woman's husband died, she went into a small tent and dressed in the worst of clothes. She did not touch perfume or anything until a year had passed. Then she was brought an animal - a donkey, a sheep, or a bird, and she would break her idda with it, by rubbing her body against it (taftaddu). Rarely did she break her idda with anything (by rubbing herself against it) but that it died. Then she would come out and would be given a piece of dung. She would throw it away and then return to whatever she wished of perfumes or whatever.' " Malik explained, 'Taftaddu' means to wipe her skin with it in the same way as with a healing charm}}
\hadithdefcmd{malik}{1266}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، عَنْ عَائِشَةَ، وَحَفْصَةَ، زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ\hadithno{1266}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Safiyya bint Abi Ubayd from A'isha and Hafsa, the wives of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, said, "It is not halal for a woman in mourning for someone who has died, if she trusts in Allah and the Last Day, to abstain from adornment for more than three nights, except for a husband}}
\hadithdefcmd{malik}{1267}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لاِمْرَأَةٍ حَادٍّ عَلَى زَوْجِهَا اشْتَكَتْ عَيْنَيْهَا فَبَلَغَ ذَلِكَ مِنْهَا اكْتَحِلِي بِكُحْلِ الْجِلاَءِ بِاللَّيْلِ وَامْسَحِيهِ بِالنَّهَارِ ‏.‏\hadithno{1267}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, said to a woman in mourning for her husband whose eyes were troubling her and the pain had become very strong, "Apply jala kohl at night and wipe it off in the day}}
\hadithdefcmd{malik}{1268}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، وَسُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُمَا كَانَا يَقُولاَنِ فِي الْمَرْأَةِ يُتَوَفَّى عَنْهَا زَوْجُهَا إِنَّهَا إِذَا خَشِيَتْ عَلَى بَصَرِهَا مِنْ رَمَدٍ أَوْ شَكْوٍ أَصَابَهَا إِنَّهَا تَكْتَحِلُ وَتَتَدَاوَى بِدَوَاءٍ أَوْ كُحْلٍ وَإِنْ كَانَ فِيهِ طِيبٌ ‏.‏ قَالَ مَالِكٌ وَإِذَا كَانَتِ الضَّرُورَةُ فَإِنَّ دِينَ اللَّهِ يُسْرٌ ‏.‏\hadithno{1268}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Salim ibn Abdullah and Sulayman ibn Yasar said that if a woman whose husband had died feared that an inflammation of her eyes might affect her sight or that some complaint might befall her, she should put kohl on and seek a remedy with kohl or some other cure even if it had perfume in it. Malik said, "If there is a necessity, the deen of Allah is ease}}
\hadithdefcmd{malik}{1269}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ صَفِيَّةَ بِنْتَ أَبِي عُبَيْدٍ، اشْتَكَتْ عَيْنَيْهَا وَهِيَ حَادٌّ عَلَى زَوْجِهَا عَبْدِ اللَّهِ بْنِ عُمَرَ فَلَمْ تَكْتَحِلْ حَتَّى كَادَتْ عَيْنَاهَا تَرْمَصَانِ ‏.‏ قَالَ مَالِكٌ تَدَّهِنُ الْمُتَوَفَّى عَنْهَا زَوْجُهَا بِالزَّيْتِ وَالشَّبْرَقِ وَمَا أَشْبَهَ ذَلِكَ إِذَا لَمْ يَكُنْ فِيهِ طِيبٌ ‏.‏ قَالَ مَالِكٌ وَلاَ تَلْبَسُ الْمَرْأَةُ الْحَادُّ عَلَى زَوْجِهَا شَيْئًا مِنَ الْحَلْىِ خَاتَمًا وَلاَ خَلْخَالاً وَلاَ غَيْرَ ذَلِكَ مِنَ الْحَلْىِ وَلاَ تَلْبَسُ شَيْئًا مِنَ الْعَصْبِ إِلاَّ أَنْ يَكُونَ عَصْبًا غَلِيظًا وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا بِشَىْءٍ مِنَ الصِّبْغِ إِلاَّ بِالسَّوَادِ وَلاَ تَمْتَشِطُ إِلاَّ بِالسِّدْرِ وَمَا أَشْبَهَهُ مِمَّا لاَ يَخْتَمِرُ فِي رَأْسِهَا ‏.‏\hadithno{1269}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Nafic that Saffiyya bint Abi Ubayd suffered from an eye-complaint while she was in mourning for her husband, Abdullah ibn Umar. She did not apply kohl until her eyes almost had ramas (a dry white secretion in the corners of the eye). Malik said, "A woman whose husband has died should anoint her eyes with olive oil and sesame oil and the like of that since there is no perfume in it." Malik said, "A woman in mourning for her husband should not put on any jewellery - rings, anklets, or such- like, neither should she dress in any sort of colourful, striped garment unless it is coarse. She should not wear any cloth dyed with anything except black, and she should only dress her hair with things like lotus-tree leaves which do not dye the hair}}
\hadithdefcmd{malik}{1270}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَى أُمِّ سَلَمَةَ وَهِيَ حَادٌّ عَلَى أَبِي سَلَمَةَ وَقَدْ جَعَلَتْ عَلَى عَيْنَيْهَا صَبِرًا فَقَالَ ‏"‏ مَا هَذَا يَا أُمَّ سَلَمَةَ ‏"‏ ‏.‏ فَقَالَتْ إِنَّمَا هُوَ صَبِرٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ اجْعَلِيهِ فِي اللَّيْلِ وَامْسَحِيهِ بِالنَّهَارِ ‏"‏ ‏.‏\hadithno{1270}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, visited Umm Salama while she was in mourning for Abu Salama and she had put aloes on her eyes. He said, "What is this, Umm Salama?" She said, "It is only aloes, Messenger of Allah." He said, "Put it on at night and wipe it off in the daytime." Malik said, "The mourning of a young girl who has not yet had a menstrual period takes the same form as the mourning of one who has had a period. She avoids what a mature woman avoids if her husband dies." Malik said, "A slave-girl mourns her husband when he dies for two months and five nights like her idda.'' Malik said, "An umm walad does not have to mourn when her master dies, and a slave-girl does not have to mourn when her master dies. Mourning is for those with husbands}}
\hadithdefcmd{malik}{1271}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ تَجْمَعُ الْحَادُّ رَأْسَهَا بِالسِّدْرِ وَالزَّيْتِ ‏.‏\hadithno{1271}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, said, "A mourning woman can rub her head with lotus leaves and olive oil}}
